# coding: utf-8

# flake8: noqa
"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


if __import__("typing").TYPE_CHECKING:
    # import models into model package
    from authentik_client.models.access_denied_challenge import AccessDeniedChallenge
    from authentik_client.models.alg_enum import AlgEnum
    from authentik_client.models.app import App
    from authentik_client.models.app_enum import AppEnum
    from authentik_client.models.apple_challenge_response_request import AppleChallengeResponseRequest
    from authentik_client.models.apple_login_challenge import AppleLoginChallenge
    from authentik_client.models.application import Application
    from authentik_client.models.application_entitlement import ApplicationEntitlement
    from authentik_client.models.application_entitlement_request import ApplicationEntitlementRequest
    from authentik_client.models.application_request import ApplicationRequest
    from authentik_client.models.auth_type_enum import AuthTypeEnum
    from authentik_client.models.authenticated_session import AuthenticatedSession
    from authentik_client.models.authenticated_session_asn import AuthenticatedSessionAsn
    from authentik_client.models.authenticated_session_geo_ip import AuthenticatedSessionGeoIp
    from authentik_client.models.authenticated_session_user_agent import AuthenticatedSessionUserAgent
    from authentik_client.models.authenticated_session_user_agent_device import AuthenticatedSessionUserAgentDevice
    from authentik_client.models.authenticated_session_user_agent_os import AuthenticatedSessionUserAgentOs
    from authentik_client.models.authenticated_session_user_agent_user_agent import AuthenticatedSessionUserAgentUserAgent
    from authentik_client.models.authentication_enum import AuthenticationEnum
    from authentik_client.models.authenticator_attachment_enum import AuthenticatorAttachmentEnum
    from authentik_client.models.authenticator_duo_challenge import AuthenticatorDuoChallenge
    from authentik_client.models.authenticator_duo_challenge_response_request import AuthenticatorDuoChallengeResponseRequest
    from authentik_client.models.authenticator_duo_stage import AuthenticatorDuoStage
    from authentik_client.models.authenticator_duo_stage_device_import_response import AuthenticatorDuoStageDeviceImportResponse
    from authentik_client.models.authenticator_duo_stage_manual_device_import_request import AuthenticatorDuoStageManualDeviceImportRequest
    from authentik_client.models.authenticator_duo_stage_request import AuthenticatorDuoStageRequest
    from authentik_client.models.authenticator_email_challenge import AuthenticatorEmailChallenge
    from authentik_client.models.authenticator_email_challenge_response_request import AuthenticatorEmailChallengeResponseRequest
    from authentik_client.models.authenticator_email_stage import AuthenticatorEmailStage
    from authentik_client.models.authenticator_email_stage_request import AuthenticatorEmailStageRequest
    from authentik_client.models.authenticator_endpoint_gdtc_stage import AuthenticatorEndpointGDTCStage
    from authentik_client.models.authenticator_endpoint_gdtc_stage_request import AuthenticatorEndpointGDTCStageRequest
    from authentik_client.models.authenticator_sms_challenge import AuthenticatorSMSChallenge
    from authentik_client.models.authenticator_sms_challenge_response_request import AuthenticatorSMSChallengeResponseRequest
    from authentik_client.models.authenticator_sms_stage import AuthenticatorSMSStage
    from authentik_client.models.authenticator_sms_stage_request import AuthenticatorSMSStageRequest
    from authentik_client.models.authenticator_static_challenge import AuthenticatorStaticChallenge
    from authentik_client.models.authenticator_static_challenge_response_request import AuthenticatorStaticChallengeResponseRequest
    from authentik_client.models.authenticator_static_stage import AuthenticatorStaticStage
    from authentik_client.models.authenticator_static_stage_request import AuthenticatorStaticStageRequest
    from authentik_client.models.authenticator_totp_challenge import AuthenticatorTOTPChallenge
    from authentik_client.models.authenticator_totp_challenge_response_request import AuthenticatorTOTPChallengeResponseRequest
    from authentik_client.models.authenticator_totp_stage import AuthenticatorTOTPStage
    from authentik_client.models.authenticator_totp_stage_request import AuthenticatorTOTPStageRequest
    from authentik_client.models.authenticator_validate_stage import AuthenticatorValidateStage
    from authentik_client.models.authenticator_validate_stage_request import AuthenticatorValidateStageRequest
    from authentik_client.models.authenticator_validation_challenge import AuthenticatorValidationChallenge
    from authentik_client.models.authenticator_validation_challenge_response_request import AuthenticatorValidationChallengeResponseRequest
    from authentik_client.models.authenticator_web_authn_challenge import AuthenticatorWebAuthnChallenge
    from authentik_client.models.authenticator_web_authn_challenge_response_request import AuthenticatorWebAuthnChallengeResponseRequest
    from authentik_client.models.authenticator_web_authn_stage import AuthenticatorWebAuthnStage
    from authentik_client.models.authenticator_web_authn_stage_request import AuthenticatorWebAuthnStageRequest
    from authentik_client.models.authorization_code_auth_method_enum import AuthorizationCodeAuthMethodEnum
    from authentik_client.models.auto_submit_challenge_response_request import AutoSubmitChallengeResponseRequest
    from authentik_client.models.autosubmit_challenge import AutosubmitChallenge
    from authentik_client.models.backends_enum import BackendsEnum
    from authentik_client.models.binding_type_enum import BindingTypeEnum
    from authentik_client.models.blueprint_file import BlueprintFile
    from authentik_client.models.blueprint_instance import BlueprintInstance
    from authentik_client.models.blueprint_instance_request import BlueprintInstanceRequest
    from authentik_client.models.blueprint_instance_status_enum import BlueprintInstanceStatusEnum
    from authentik_client.models.brand import Brand
    from authentik_client.models.brand_request import BrandRequest
    from authentik_client.models.cache import Cache
    from authentik_client.models.capabilities_enum import CapabilitiesEnum
    from authentik_client.models.captcha_challenge import CaptchaChallenge
    from authentik_client.models.captcha_challenge_response_request import CaptchaChallengeResponseRequest
    from authentik_client.models.captcha_stage import CaptchaStage
    from authentik_client.models.captcha_stage_request import CaptchaStageRequest
    from authentik_client.models.cert_attribute_enum import CertAttributeEnum
    from authentik_client.models.certificate_data import CertificateData
    from authentik_client.models.certificate_generation_request import CertificateGenerationRequest
    from authentik_client.models.certificate_key_pair import CertificateKeyPair
    from authentik_client.models.certificate_key_pair_request import CertificateKeyPairRequest
    from authentik_client.models.challenge_types import ChallengeTypes
    from authentik_client.models.client_type_enum import ClientTypeEnum
    from authentik_client.models.compatibility_mode_enum import CompatibilityModeEnum
    from authentik_client.models.config import Config
    from authentik_client.models.connection_token import ConnectionToken
    from authentik_client.models.connection_token_request import ConnectionTokenRequest
    from authentik_client.models.consent_challenge import ConsentChallenge
    from authentik_client.models.consent_challenge_response_request import ConsentChallengeResponseRequest
    from authentik_client.models.consent_permission import ConsentPermission
    from authentik_client.models.consent_stage import ConsentStage
    from authentik_client.models.consent_stage_mode_enum import ConsentStageModeEnum
    from authentik_client.models.consent_stage_request import ConsentStageRequest
    from authentik_client.models.contextual_flow_info import ContextualFlowInfo
    from authentik_client.models.contextual_flow_info_layout_enum import ContextualFlowInfoLayoutEnum
    from authentik_client.models.country_code_enum import CountryCodeEnum
    from authentik_client.models.current_brand import CurrentBrand
    from authentik_client.models.current_brand_flags import CurrentBrandFlags
    from authentik_client.models.delivery_method_enum import DeliveryMethodEnum
    from authentik_client.models.denied_action_enum import DeniedActionEnum
    from authentik_client.models.deny_stage import DenyStage
    from authentik_client.models.deny_stage_request import DenyStageRequest
    from authentik_client.models.detailed_country import DetailedCountry
    from authentik_client.models.detailed_country_field import DetailedCountryField
    from authentik_client.models.device import Device
    from authentik_client.models.device_challenge import DeviceChallenge
    from authentik_client.models.device_challenge_request import DeviceChallengeRequest
    from authentik_client.models.device_classes_enum import DeviceClassesEnum
    from authentik_client.models.digest_algorithm_enum import DigestAlgorithmEnum
    from authentik_client.models.digits_enum import DigitsEnum
    from authentik_client.models.docker_service_connection import DockerServiceConnection
    from authentik_client.models.docker_service_connection_request import DockerServiceConnectionRequest
    from authentik_client.models.domain import Domain
    from authentik_client.models.domain_request import DomainRequest
    from authentik_client.models.dummy_challenge import DummyChallenge
    from authentik_client.models.dummy_challenge_response_request import DummyChallengeResponseRequest
    from authentik_client.models.dummy_policy import DummyPolicy
    from authentik_client.models.dummy_policy_request import DummyPolicyRequest
    from authentik_client.models.dummy_stage import DummyStage
    from authentik_client.models.dummy_stage_request import DummyStageRequest
    from authentik_client.models.duo_device import DuoDevice
    from authentik_client.models.duo_device_enrollment_status import DuoDeviceEnrollmentStatus
    from authentik_client.models.duo_device_request import DuoDeviceRequest
    from authentik_client.models.duo_response_enum import DuoResponseEnum
    from authentik_client.models.email_challenge import EmailChallenge
    from authentik_client.models.email_challenge_response_request import EmailChallengeResponseRequest
    from authentik_client.models.email_device import EmailDevice
    from authentik_client.models.email_device_request import EmailDeviceRequest
    from authentik_client.models.email_stage import EmailStage
    from authentik_client.models.email_stage_request import EmailStageRequest
    from authentik_client.models.endpoint import Endpoint
    from authentik_client.models.endpoint_auth_mode_enum import EndpointAuthModeEnum
    from authentik_client.models.endpoint_device import EndpointDevice
    from authentik_client.models.endpoint_device_request import EndpointDeviceRequest
    from authentik_client.models.endpoint_request import EndpointRequest
    from authentik_client.models.error_detail import ErrorDetail
    from authentik_client.models.error_reporting_config import ErrorReportingConfig
    from authentik_client.models.event import Event
    from authentik_client.models.event_actions import EventActions
    from authentik_client.models.event_matcher_policy import EventMatcherPolicy
    from authentik_client.models.event_matcher_policy_request import EventMatcherPolicyRequest
    from authentik_client.models.event_request import EventRequest
    from authentik_client.models.event_top_per_user import EventTopPerUser
    from authentik_client.models.event_volume import EventVolume
    from authentik_client.models.events_requested_enum import EventsRequestedEnum
    from authentik_client.models.expiring_base_grant_model import ExpiringBaseGrantModel
    from authentik_client.models.expression_policy import ExpressionPolicy
    from authentik_client.models.expression_policy_request import ExpressionPolicyRequest
    from authentik_client.models.extra_role_object_permission import ExtraRoleObjectPermission
    from authentik_client.models.extra_role_object_permission_request import ExtraRoleObjectPermissionRequest
    from authentik_client.models.extra_user_object_permission import ExtraUserObjectPermission
    from authentik_client.models.extra_user_object_permission_request import ExtraUserObjectPermissionRequest
    from authentik_client.models.file_path_request import FilePathRequest
    from authentik_client.models.flow import Flow
    from authentik_client.models.flow_challenge_response_request import FlowChallengeResponseRequest
    from authentik_client.models.flow_designation_enum import FlowDesignationEnum
    from authentik_client.models.flow_diagram import FlowDiagram
    from authentik_client.models.flow_error_challenge import FlowErrorChallenge
    from authentik_client.models.flow_import_result import FlowImportResult
    from authentik_client.models.flow_inspection import FlowInspection
    from authentik_client.models.flow_inspector_plan import FlowInspectorPlan
    from authentik_client.models.flow_layout_enum import FlowLayoutEnum
    from authentik_client.models.flow_request import FlowRequest
    from authentik_client.models.flow_set import FlowSet
    from authentik_client.models.flow_set_request import FlowSetRequest
    from authentik_client.models.flow_stage_binding import FlowStageBinding
    from authentik_client.models.flow_stage_binding_request import FlowStageBindingRequest
    from authentik_client.models.footer_link import FooterLink
    from authentik_client.models.frame_challenge import FrameChallenge
    from authentik_client.models.frame_challenge_response_request import FrameChallengeResponseRequest
    from authentik_client.models.generic_error import GenericError
    from authentik_client.models.geo_ip_policy import GeoIPPolicy
    from authentik_client.models.geo_ip_policy_request import GeoIPPolicyRequest
    from authentik_client.models.geoip_binding_enum import GeoipBindingEnum
    from authentik_client.models.google_workspace_provider import GoogleWorkspaceProvider
    from authentik_client.models.google_workspace_provider_group import GoogleWorkspaceProviderGroup
    from authentik_client.models.google_workspace_provider_group_request import GoogleWorkspaceProviderGroupRequest
    from authentik_client.models.google_workspace_provider_mapping import GoogleWorkspaceProviderMapping
    from authentik_client.models.google_workspace_provider_mapping_request import GoogleWorkspaceProviderMappingRequest
    from authentik_client.models.google_workspace_provider_request import GoogleWorkspaceProviderRequest
    from authentik_client.models.google_workspace_provider_user import GoogleWorkspaceProviderUser
    from authentik_client.models.google_workspace_provider_user_request import GoogleWorkspaceProviderUserRequest
    from authentik_client.models.group import Group
    from authentik_client.models.group_child import GroupChild
    from authentik_client.models.group_kerberos_source_connection import GroupKerberosSourceConnection
    from authentik_client.models.group_kerberos_source_connection_request import GroupKerberosSourceConnectionRequest
    from authentik_client.models.group_ldap_source_connection import GroupLDAPSourceConnection
    from authentik_client.models.group_ldap_source_connection_request import GroupLDAPSourceConnectionRequest
    from authentik_client.models.group_matching_mode_enum import GroupMatchingModeEnum
    from authentik_client.models.group_o_auth_source_connection import GroupOAuthSourceConnection
    from authentik_client.models.group_o_auth_source_connection_request import GroupOAuthSourceConnectionRequest
    from authentik_client.models.group_plex_source_connection import GroupPlexSourceConnection
    from authentik_client.models.group_plex_source_connection_request import GroupPlexSourceConnectionRequest
    from authentik_client.models.group_request import GroupRequest
    from authentik_client.models.group_saml_source_connection import GroupSAMLSourceConnection
    from authentik_client.models.group_saml_source_connection_request import GroupSAMLSourceConnectionRequest
    from authentik_client.models.group_source_connection import GroupSourceConnection
    from authentik_client.models.group_source_connection_request import GroupSourceConnectionRequest
    from authentik_client.models.group_telegram_source_connection import GroupTelegramSourceConnection
    from authentik_client.models.group_telegram_source_connection_request import GroupTelegramSourceConnectionRequest
    from authentik_client.models.identification_challenge import IdentificationChallenge
    from authentik_client.models.identification_challenge_response_request import IdentificationChallengeResponseRequest
    from authentik_client.models.identification_stage import IdentificationStage
    from authentik_client.models.identification_stage_request import IdentificationStageRequest
    from authentik_client.models.impersonation_request import ImpersonationRequest
    from authentik_client.models.initial_permissions import InitialPermissions
    from authentik_client.models.initial_permissions_mode_enum import InitialPermissionsModeEnum
    from authentik_client.models.initial_permissions_request import InitialPermissionsRequest
    from authentik_client.models.install_id import InstallID
    from authentik_client.models.intent_enum import IntentEnum
    from authentik_client.models.invalid_response_action_enum import InvalidResponseActionEnum
    from authentik_client.models.invitation import Invitation
    from authentik_client.models.invitation_request import InvitationRequest
    from authentik_client.models.invitation_stage import InvitationStage
    from authentik_client.models.invitation_stage_request import InvitationStageRequest
    from authentik_client.models.issuer_mode_enum import IssuerModeEnum
    from authentik_client.models.kadmin_type_enum import KadminTypeEnum
    from authentik_client.models.kerberos_source import KerberosSource
    from authentik_client.models.kerberos_source_property_mapping import KerberosSourcePropertyMapping
    from authentik_client.models.kerberos_source_property_mapping_request import KerberosSourcePropertyMappingRequest
    from authentik_client.models.kerberos_source_request import KerberosSourceRequest
    from authentik_client.models.kubernetes_service_connection import KubernetesServiceConnection
    from authentik_client.models.kubernetes_service_connection_request import KubernetesServiceConnectionRequest
    from authentik_client.models.ldapapi_access_mode import LDAPAPIAccessMode
    from authentik_client.models.ldap_check_access import LDAPCheckAccess
    from authentik_client.models.ldap_debug import LDAPDebug
    from authentik_client.models.ldap_outpost_config import LDAPOutpostConfig
    from authentik_client.models.ldap_provider import LDAPProvider
    from authentik_client.models.ldap_provider_request import LDAPProviderRequest
    from authentik_client.models.ldap_source import LDAPSource
    from authentik_client.models.ldap_source_property_mapping import LDAPSourcePropertyMapping
    from authentik_client.models.ldap_source_property_mapping_request import LDAPSourcePropertyMappingRequest
    from authentik_client.models.ldap_source_request import LDAPSourceRequest
    from authentik_client.models.last_task_status_enum import LastTaskStatusEnum
    from authentik_client.models.license import License
    from authentik_client.models.license_flags_enum import LicenseFlagsEnum
    from authentik_client.models.license_forecast import LicenseForecast
    from authentik_client.models.license_request import LicenseRequest
    from authentik_client.models.license_summary import LicenseSummary
    from authentik_client.models.license_summary_status_enum import LicenseSummaryStatusEnum
    from authentik_client.models.link import Link
    from authentik_client.models.log_event import LogEvent
    from authentik_client.models.log_level_enum import LogLevelEnum
    from authentik_client.models.login_challenge_types import LoginChallengeTypes
    from authentik_client.models.login_source import LoginSource
    from authentik_client.models.matching_mode_enum import MatchingModeEnum
    from authentik_client.models.metadata import Metadata
    from authentik_client.models.microsoft_entra_provider import MicrosoftEntraProvider
    from authentik_client.models.microsoft_entra_provider_group import MicrosoftEntraProviderGroup
    from authentik_client.models.microsoft_entra_provider_group_request import MicrosoftEntraProviderGroupRequest
    from authentik_client.models.microsoft_entra_provider_mapping import MicrosoftEntraProviderMapping
    from authentik_client.models.microsoft_entra_provider_mapping_request import MicrosoftEntraProviderMappingRequest
    from authentik_client.models.microsoft_entra_provider_request import MicrosoftEntraProviderRequest
    from authentik_client.models.microsoft_entra_provider_user import MicrosoftEntraProviderUser
    from authentik_client.models.microsoft_entra_provider_user_request import MicrosoftEntraProviderUserRequest
    from authentik_client.models.model_enum import ModelEnum
    from authentik_client.models.model_request import ModelRequest
    from authentik_client.models.mutual_tls_stage import MutualTLSStage
    from authentik_client.models.mutual_tls_stage_mode_enum import MutualTLSStageModeEnum
    from authentik_client.models.mutual_tls_stage_request import MutualTLSStageRequest
    from authentik_client.models.network_binding_enum import NetworkBindingEnum
    from authentik_client.models.not_configured_action_enum import NotConfiguredActionEnum
    from authentik_client.models.notification import Notification
    from authentik_client.models.notification_request import NotificationRequest
    from authentik_client.models.notification_rule import NotificationRule
    from authentik_client.models.notification_rule_request import NotificationRuleRequest
    from authentik_client.models.notification_transport import NotificationTransport
    from authentik_client.models.notification_transport_mode_enum import NotificationTransportModeEnum
    from authentik_client.models.notification_transport_request import NotificationTransportRequest
    from authentik_client.models.notification_transport_test import NotificationTransportTest
    from authentik_client.models.notification_webhook_mapping import NotificationWebhookMapping
    from authentik_client.models.notification_webhook_mapping_request import NotificationWebhookMappingRequest
    from authentik_client.models.o_auth2_provider import OAuth2Provider
    from authentik_client.models.o_auth2_provider_request import OAuth2ProviderRequest
    from authentik_client.models.o_auth2_provider_setup_urls import OAuth2ProviderSetupURLs
    from authentik_client.models.o_auth_device_code_challenge import OAuthDeviceCodeChallenge
    from authentik_client.models.o_auth_device_code_challenge_response_request import OAuthDeviceCodeChallengeResponseRequest
    from authentik_client.models.o_auth_device_code_finish_challenge import OAuthDeviceCodeFinishChallenge
    from authentik_client.models.o_auth_device_code_finish_challenge_response_request import OAuthDeviceCodeFinishChallengeResponseRequest
    from authentik_client.models.o_auth_source import OAuthSource
    from authentik_client.models.o_auth_source_property_mapping import OAuthSourcePropertyMapping
    from authentik_client.models.o_auth_source_property_mapping_request import OAuthSourcePropertyMappingRequest
    from authentik_client.models.o_auth_source_request import OAuthSourceRequest
    from authentik_client.models.open_id_connect_configuration import OpenIDConnectConfiguration
    from authentik_client.models.outgoing_sync_delete_action import OutgoingSyncDeleteAction
    from authentik_client.models.outpost import Outpost
    from authentik_client.models.outpost_default_config import OutpostDefaultConfig
    from authentik_client.models.outpost_health import OutpostHealth
    from authentik_client.models.outpost_request import OutpostRequest
    from authentik_client.models.outpost_type_enum import OutpostTypeEnum
    from authentik_client.models.paginated_application_entitlement_list import PaginatedApplicationEntitlementList
    from authentik_client.models.paginated_application_list import PaginatedApplicationList
    from authentik_client.models.paginated_authenticated_session_list import PaginatedAuthenticatedSessionList
    from authentik_client.models.paginated_authenticator_duo_stage_list import PaginatedAuthenticatorDuoStageList
    from authentik_client.models.paginated_authenticator_email_stage_list import PaginatedAuthenticatorEmailStageList
    from authentik_client.models.paginated_authenticator_endpoint_gdtc_stage_list import PaginatedAuthenticatorEndpointGDTCStageList
    from authentik_client.models.paginated_authenticator_sms_stage_list import PaginatedAuthenticatorSMSStageList
    from authentik_client.models.paginated_authenticator_static_stage_list import PaginatedAuthenticatorStaticStageList
    from authentik_client.models.paginated_authenticator_totp_stage_list import PaginatedAuthenticatorTOTPStageList
    from authentik_client.models.paginated_authenticator_validate_stage_list import PaginatedAuthenticatorValidateStageList
    from authentik_client.models.paginated_authenticator_web_authn_stage_list import PaginatedAuthenticatorWebAuthnStageList
    from authentik_client.models.paginated_blueprint_instance_list import PaginatedBlueprintInstanceList
    from authentik_client.models.paginated_brand_list import PaginatedBrandList
    from authentik_client.models.paginated_captcha_stage_list import PaginatedCaptchaStageList
    from authentik_client.models.paginated_certificate_key_pair_list import PaginatedCertificateKeyPairList
    from authentik_client.models.paginated_connection_token_list import PaginatedConnectionTokenList
    from authentik_client.models.paginated_consent_stage_list import PaginatedConsentStageList
    from authentik_client.models.paginated_deny_stage_list import PaginatedDenyStageList
    from authentik_client.models.paginated_docker_service_connection_list import PaginatedDockerServiceConnectionList
    from authentik_client.models.paginated_domain_list import PaginatedDomainList
    from authentik_client.models.paginated_dummy_policy_list import PaginatedDummyPolicyList
    from authentik_client.models.paginated_dummy_stage_list import PaginatedDummyStageList
    from authentik_client.models.paginated_duo_device_list import PaginatedDuoDeviceList
    from authentik_client.models.paginated_email_device_list import PaginatedEmailDeviceList
    from authentik_client.models.paginated_email_stage_list import PaginatedEmailStageList
    from authentik_client.models.paginated_endpoint_device_list import PaginatedEndpointDeviceList
    from authentik_client.models.paginated_endpoint_list import PaginatedEndpointList
    from authentik_client.models.paginated_event_list import PaginatedEventList
    from authentik_client.models.paginated_event_matcher_policy_list import PaginatedEventMatcherPolicyList
    from authentik_client.models.paginated_expiring_base_grant_model_list import PaginatedExpiringBaseGrantModelList
    from authentik_client.models.paginated_expression_policy_list import PaginatedExpressionPolicyList
    from authentik_client.models.paginated_extra_role_object_permission_list import PaginatedExtraRoleObjectPermissionList
    from authentik_client.models.paginated_extra_user_object_permission_list import PaginatedExtraUserObjectPermissionList
    from authentik_client.models.paginated_flow_list import PaginatedFlowList
    from authentik_client.models.paginated_flow_stage_binding_list import PaginatedFlowStageBindingList
    from authentik_client.models.paginated_geo_ip_policy_list import PaginatedGeoIPPolicyList
    from authentik_client.models.paginated_google_workspace_provider_group_list import PaginatedGoogleWorkspaceProviderGroupList
    from authentik_client.models.paginated_google_workspace_provider_list import PaginatedGoogleWorkspaceProviderList
    from authentik_client.models.paginated_google_workspace_provider_mapping_list import PaginatedGoogleWorkspaceProviderMappingList
    from authentik_client.models.paginated_google_workspace_provider_user_list import PaginatedGoogleWorkspaceProviderUserList
    from authentik_client.models.paginated_group_kerberos_source_connection_list import PaginatedGroupKerberosSourceConnectionList
    from authentik_client.models.paginated_group_ldap_source_connection_list import PaginatedGroupLDAPSourceConnectionList
    from authentik_client.models.paginated_group_list import PaginatedGroupList
    from authentik_client.models.paginated_group_o_auth_source_connection_list import PaginatedGroupOAuthSourceConnectionList
    from authentik_client.models.paginated_group_plex_source_connection_list import PaginatedGroupPlexSourceConnectionList
    from authentik_client.models.paginated_group_saml_source_connection_list import PaginatedGroupSAMLSourceConnectionList
    from authentik_client.models.paginated_group_source_connection_list import PaginatedGroupSourceConnectionList
    from authentik_client.models.paginated_group_telegram_source_connection_list import PaginatedGroupTelegramSourceConnectionList
    from authentik_client.models.paginated_identification_stage_list import PaginatedIdentificationStageList
    from authentik_client.models.paginated_initial_permissions_list import PaginatedInitialPermissionsList
    from authentik_client.models.paginated_invitation_list import PaginatedInvitationList
    from authentik_client.models.paginated_invitation_stage_list import PaginatedInvitationStageList
    from authentik_client.models.paginated_kerberos_source_list import PaginatedKerberosSourceList
    from authentik_client.models.paginated_kerberos_source_property_mapping_list import PaginatedKerberosSourcePropertyMappingList
    from authentik_client.models.paginated_kubernetes_service_connection_list import PaginatedKubernetesServiceConnectionList
    from authentik_client.models.paginated_ldap_outpost_config_list import PaginatedLDAPOutpostConfigList
    from authentik_client.models.paginated_ldap_provider_list import PaginatedLDAPProviderList
    from authentik_client.models.paginated_ldap_source_list import PaginatedLDAPSourceList
    from authentik_client.models.paginated_ldap_source_property_mapping_list import PaginatedLDAPSourcePropertyMappingList
    from authentik_client.models.paginated_license_list import PaginatedLicenseList
    from authentik_client.models.paginated_microsoft_entra_provider_group_list import PaginatedMicrosoftEntraProviderGroupList
    from authentik_client.models.paginated_microsoft_entra_provider_list import PaginatedMicrosoftEntraProviderList
    from authentik_client.models.paginated_microsoft_entra_provider_mapping_list import PaginatedMicrosoftEntraProviderMappingList
    from authentik_client.models.paginated_microsoft_entra_provider_user_list import PaginatedMicrosoftEntraProviderUserList
    from authentik_client.models.paginated_mutual_tls_stage_list import PaginatedMutualTLSStageList
    from authentik_client.models.paginated_notification_list import PaginatedNotificationList
    from authentik_client.models.paginated_notification_rule_list import PaginatedNotificationRuleList
    from authentik_client.models.paginated_notification_transport_list import PaginatedNotificationTransportList
    from authentik_client.models.paginated_notification_webhook_mapping_list import PaginatedNotificationWebhookMappingList
    from authentik_client.models.paginated_o_auth2_provider_list import PaginatedOAuth2ProviderList
    from authentik_client.models.paginated_o_auth_source_list import PaginatedOAuthSourceList
    from authentik_client.models.paginated_o_auth_source_property_mapping_list import PaginatedOAuthSourcePropertyMappingList
    from authentik_client.models.paginated_outpost_list import PaginatedOutpostList
    from authentik_client.models.paginated_password_expiry_policy_list import PaginatedPasswordExpiryPolicyList
    from authentik_client.models.paginated_password_policy_list import PaginatedPasswordPolicyList
    from authentik_client.models.paginated_password_stage_list import PaginatedPasswordStageList
    from authentik_client.models.paginated_permission_list import PaginatedPermissionList
    from authentik_client.models.paginated_plex_source_list import PaginatedPlexSourceList
    from authentik_client.models.paginated_plex_source_property_mapping_list import PaginatedPlexSourcePropertyMappingList
    from authentik_client.models.paginated_policy_binding_list import PaginatedPolicyBindingList
    from authentik_client.models.paginated_policy_list import PaginatedPolicyList
    from authentik_client.models.paginated_prompt_list import PaginatedPromptList
    from authentik_client.models.paginated_prompt_stage_list import PaginatedPromptStageList
    from authentik_client.models.paginated_property_mapping_list import PaginatedPropertyMappingList
    from authentik_client.models.paginated_provider_list import PaginatedProviderList
    from authentik_client.models.paginated_proxy_outpost_config_list import PaginatedProxyOutpostConfigList
    from authentik_client.models.paginated_proxy_provider_list import PaginatedProxyProviderList
    from authentik_client.models.paginated_rac_property_mapping_list import PaginatedRACPropertyMappingList
    from authentik_client.models.paginated_rac_provider_list import PaginatedRACProviderList
    from authentik_client.models.paginated_radius_outpost_config_list import PaginatedRadiusOutpostConfigList
    from authentik_client.models.paginated_radius_provider_list import PaginatedRadiusProviderList
    from authentik_client.models.paginated_radius_provider_property_mapping_list import PaginatedRadiusProviderPropertyMappingList
    from authentik_client.models.paginated_redirect_stage_list import PaginatedRedirectStageList
    from authentik_client.models.paginated_reputation_list import PaginatedReputationList
    from authentik_client.models.paginated_reputation_policy_list import PaginatedReputationPolicyList
    from authentik_client.models.paginated_role_assigned_object_permission_list import PaginatedRoleAssignedObjectPermissionList
    from authentik_client.models.paginated_role_list import PaginatedRoleList
    from authentik_client.models.paginated_saml_property_mapping_list import PaginatedSAMLPropertyMappingList
    from authentik_client.models.paginated_saml_provider_list import PaginatedSAMLProviderList
    from authentik_client.models.paginated_saml_source_list import PaginatedSAMLSourceList
    from authentik_client.models.paginated_saml_source_property_mapping_list import PaginatedSAMLSourcePropertyMappingList
    from authentik_client.models.paginated_scim_mapping_list import PaginatedSCIMMappingList
    from authentik_client.models.paginated_scim_provider_group_list import PaginatedSCIMProviderGroupList
    from authentik_client.models.paginated_scim_provider_list import PaginatedSCIMProviderList
    from authentik_client.models.paginated_scim_provider_user_list import PaginatedSCIMProviderUserList
    from authentik_client.models.paginated_scim_source_group_list import PaginatedSCIMSourceGroupList
    from authentik_client.models.paginated_scim_source_list import PaginatedSCIMSourceList
    from authentik_client.models.paginated_scim_source_property_mapping_list import PaginatedSCIMSourcePropertyMappingList
    from authentik_client.models.paginated_scim_source_user_list import PaginatedSCIMSourceUserList
    from authentik_client.models.paginated_sms_device_list import PaginatedSMSDeviceList
    from authentik_client.models.paginated_ssf_provider_list import PaginatedSSFProviderList
    from authentik_client.models.paginated_ssf_stream_list import PaginatedSSFStreamList
    from authentik_client.models.paginated_schedule_list import PaginatedScheduleList
    from authentik_client.models.paginated_scope_mapping_list import PaginatedScopeMappingList
    from authentik_client.models.paginated_service_connection_list import PaginatedServiceConnectionList
    from authentik_client.models.paginated_source_list import PaginatedSourceList
    from authentik_client.models.paginated_source_stage_list import PaginatedSourceStageList
    from authentik_client.models.paginated_stage_list import PaginatedStageList
    from authentik_client.models.paginated_static_device_list import PaginatedStaticDeviceList
    from authentik_client.models.paginated_totp_device_list import PaginatedTOTPDeviceList
    from authentik_client.models.paginated_task_list import PaginatedTaskList
    from authentik_client.models.paginated_telegram_source_list import PaginatedTelegramSourceList
    from authentik_client.models.paginated_telegram_source_property_mapping_list import PaginatedTelegramSourcePropertyMappingList
    from authentik_client.models.paginated_tenant_list import PaginatedTenantList
    from authentik_client.models.paginated_token_list import PaginatedTokenList
    from authentik_client.models.paginated_token_model_list import PaginatedTokenModelList
    from authentik_client.models.paginated_unique_password_policy_list import PaginatedUniquePasswordPolicyList
    from authentik_client.models.paginated_user_assigned_object_permission_list import PaginatedUserAssignedObjectPermissionList
    from authentik_client.models.paginated_user_consent_list import PaginatedUserConsentList
    from authentik_client.models.paginated_user_delete_stage_list import PaginatedUserDeleteStageList
    from authentik_client.models.paginated_user_kerberos_source_connection_list import PaginatedUserKerberosSourceConnectionList
    from authentik_client.models.paginated_user_ldap_source_connection_list import PaginatedUserLDAPSourceConnectionList
    from authentik_client.models.paginated_user_list import PaginatedUserList
    from authentik_client.models.paginated_user_login_stage_list import PaginatedUserLoginStageList
    from authentik_client.models.paginated_user_logout_stage_list import PaginatedUserLogoutStageList
    from authentik_client.models.paginated_user_o_auth_source_connection_list import PaginatedUserOAuthSourceConnectionList
    from authentik_client.models.paginated_user_plex_source_connection_list import PaginatedUserPlexSourceConnectionList
    from authentik_client.models.paginated_user_saml_source_connection_list import PaginatedUserSAMLSourceConnectionList
    from authentik_client.models.paginated_user_source_connection_list import PaginatedUserSourceConnectionList
    from authentik_client.models.paginated_user_telegram_source_connection_list import PaginatedUserTelegramSourceConnectionList
    from authentik_client.models.paginated_user_write_stage_list import PaginatedUserWriteStageList
    from authentik_client.models.paginated_web_authn_device_list import PaginatedWebAuthnDeviceList
    from authentik_client.models.paginated_web_authn_device_type_list import PaginatedWebAuthnDeviceTypeList
    from authentik_client.models.pagination import Pagination
    from authentik_client.models.partial_group import PartialGroup
    from authentik_client.models.partial_user import PartialUser
    from authentik_client.models.password_challenge import PasswordChallenge
    from authentik_client.models.password_challenge_response_request import PasswordChallengeResponseRequest
    from authentik_client.models.password_expiry_policy import PasswordExpiryPolicy
    from authentik_client.models.password_expiry_policy_request import PasswordExpiryPolicyRequest
    from authentik_client.models.password_policy import PasswordPolicy
    from authentik_client.models.password_policy_request import PasswordPolicyRequest
    from authentik_client.models.password_stage import PasswordStage
    from authentik_client.models.password_stage_request import PasswordStageRequest
    from authentik_client.models.patched_application_entitlement_request import PatchedApplicationEntitlementRequest
    from authentik_client.models.patched_application_request import PatchedApplicationRequest
    from authentik_client.models.patched_authenticator_duo_stage_request import PatchedAuthenticatorDuoStageRequest
    from authentik_client.models.patched_authenticator_email_stage_request import PatchedAuthenticatorEmailStageRequest
    from authentik_client.models.patched_authenticator_endpoint_gdtc_stage_request import PatchedAuthenticatorEndpointGDTCStageRequest
    from authentik_client.models.patched_authenticator_sms_stage_request import PatchedAuthenticatorSMSStageRequest
    from authentik_client.models.patched_authenticator_static_stage_request import PatchedAuthenticatorStaticStageRequest
    from authentik_client.models.patched_authenticator_totp_stage_request import PatchedAuthenticatorTOTPStageRequest
    from authentik_client.models.patched_authenticator_validate_stage_request import PatchedAuthenticatorValidateStageRequest
    from authentik_client.models.patched_authenticator_web_authn_stage_request import PatchedAuthenticatorWebAuthnStageRequest
    from authentik_client.models.patched_blueprint_instance_request import PatchedBlueprintInstanceRequest
    from authentik_client.models.patched_brand_request import PatchedBrandRequest
    from authentik_client.models.patched_captcha_stage_request import PatchedCaptchaStageRequest
    from authentik_client.models.patched_certificate_key_pair_request import PatchedCertificateKeyPairRequest
    from authentik_client.models.patched_connection_token_request import PatchedConnectionTokenRequest
    from authentik_client.models.patched_consent_stage_request import PatchedConsentStageRequest
    from authentik_client.models.patched_deny_stage_request import PatchedDenyStageRequest
    from authentik_client.models.patched_docker_service_connection_request import PatchedDockerServiceConnectionRequest
    from authentik_client.models.patched_domain_request import PatchedDomainRequest
    from authentik_client.models.patched_dummy_policy_request import PatchedDummyPolicyRequest
    from authentik_client.models.patched_dummy_stage_request import PatchedDummyStageRequest
    from authentik_client.models.patched_duo_device_request import PatchedDuoDeviceRequest
    from authentik_client.models.patched_email_device_request import PatchedEmailDeviceRequest
    from authentik_client.models.patched_email_stage_request import PatchedEmailStageRequest
    from authentik_client.models.patched_endpoint_device_request import PatchedEndpointDeviceRequest
    from authentik_client.models.patched_endpoint_request import PatchedEndpointRequest
    from authentik_client.models.patched_event_matcher_policy_request import PatchedEventMatcherPolicyRequest
    from authentik_client.models.patched_event_request import PatchedEventRequest
    from authentik_client.models.patched_expression_policy_request import PatchedExpressionPolicyRequest
    from authentik_client.models.patched_extra_role_object_permission_request import PatchedExtraRoleObjectPermissionRequest
    from authentik_client.models.patched_extra_user_object_permission_request import PatchedExtraUserObjectPermissionRequest
    from authentik_client.models.patched_flow_request import PatchedFlowRequest
    from authentik_client.models.patched_flow_stage_binding_request import PatchedFlowStageBindingRequest
    from authentik_client.models.patched_geo_ip_policy_request import PatchedGeoIPPolicyRequest
    from authentik_client.models.patched_google_workspace_provider_mapping_request import PatchedGoogleWorkspaceProviderMappingRequest
    from authentik_client.models.patched_google_workspace_provider_request import PatchedGoogleWorkspaceProviderRequest
    from authentik_client.models.patched_group_kerberos_source_connection_request import PatchedGroupKerberosSourceConnectionRequest
    from authentik_client.models.patched_group_ldap_source_connection_request import PatchedGroupLDAPSourceConnectionRequest
    from authentik_client.models.patched_group_o_auth_source_connection_request import PatchedGroupOAuthSourceConnectionRequest
    from authentik_client.models.patched_group_plex_source_connection_request import PatchedGroupPlexSourceConnectionRequest
    from authentik_client.models.patched_group_request import PatchedGroupRequest
    from authentik_client.models.patched_group_saml_source_connection_request import PatchedGroupSAMLSourceConnectionRequest
    from authentik_client.models.patched_group_source_connection_request import PatchedGroupSourceConnectionRequest
    from authentik_client.models.patched_group_telegram_source_connection_request import PatchedGroupTelegramSourceConnectionRequest
    from authentik_client.models.patched_identification_stage_request import PatchedIdentificationStageRequest
    from authentik_client.models.patched_initial_permissions_request import PatchedInitialPermissionsRequest
    from authentik_client.models.patched_invitation_request import PatchedInvitationRequest
    from authentik_client.models.patched_invitation_stage_request import PatchedInvitationStageRequest
    from authentik_client.models.patched_kerberos_source_property_mapping_request import PatchedKerberosSourcePropertyMappingRequest
    from authentik_client.models.patched_kerberos_source_request import PatchedKerberosSourceRequest
    from authentik_client.models.patched_kubernetes_service_connection_request import PatchedKubernetesServiceConnectionRequest
    from authentik_client.models.patched_ldap_provider_request import PatchedLDAPProviderRequest
    from authentik_client.models.patched_ldap_source_property_mapping_request import PatchedLDAPSourcePropertyMappingRequest
    from authentik_client.models.patched_ldap_source_request import PatchedLDAPSourceRequest
    from authentik_client.models.patched_license_request import PatchedLicenseRequest
    from authentik_client.models.patched_microsoft_entra_provider_mapping_request import PatchedMicrosoftEntraProviderMappingRequest
    from authentik_client.models.patched_microsoft_entra_provider_request import PatchedMicrosoftEntraProviderRequest
    from authentik_client.models.patched_mutual_tls_stage_request import PatchedMutualTLSStageRequest
    from authentik_client.models.patched_notification_request import PatchedNotificationRequest
    from authentik_client.models.patched_notification_rule_request import PatchedNotificationRuleRequest
    from authentik_client.models.patched_notification_transport_request import PatchedNotificationTransportRequest
    from authentik_client.models.patched_notification_webhook_mapping_request import PatchedNotificationWebhookMappingRequest
    from authentik_client.models.patched_o_auth2_provider_request import PatchedOAuth2ProviderRequest
    from authentik_client.models.patched_o_auth_source_property_mapping_request import PatchedOAuthSourcePropertyMappingRequest
    from authentik_client.models.patched_o_auth_source_request import PatchedOAuthSourceRequest
    from authentik_client.models.patched_outpost_request import PatchedOutpostRequest
    from authentik_client.models.patched_password_expiry_policy_request import PatchedPasswordExpiryPolicyRequest
    from authentik_client.models.patched_password_policy_request import PatchedPasswordPolicyRequest
    from authentik_client.models.patched_password_stage_request import PatchedPasswordStageRequest
    from authentik_client.models.patched_permission_assign_request import PatchedPermissionAssignRequest
    from authentik_client.models.patched_plex_source_property_mapping_request import PatchedPlexSourcePropertyMappingRequest
    from authentik_client.models.patched_plex_source_request import PatchedPlexSourceRequest
    from authentik_client.models.patched_policy_binding_request import PatchedPolicyBindingRequest
    from authentik_client.models.patched_prompt_request import PatchedPromptRequest
    from authentik_client.models.patched_prompt_stage_request import PatchedPromptStageRequest
    from authentik_client.models.patched_proxy_provider_request import PatchedProxyProviderRequest
    from authentik_client.models.patched_rac_property_mapping_request import PatchedRACPropertyMappingRequest
    from authentik_client.models.patched_rac_provider_request import PatchedRACProviderRequest
    from authentik_client.models.patched_radius_provider_property_mapping_request import PatchedRadiusProviderPropertyMappingRequest
    from authentik_client.models.patched_radius_provider_request import PatchedRadiusProviderRequest
    from authentik_client.models.patched_redirect_stage_request import PatchedRedirectStageRequest
    from authentik_client.models.patched_reputation_policy_request import PatchedReputationPolicyRequest
    from authentik_client.models.patched_role_request import PatchedRoleRequest
    from authentik_client.models.patched_saml_property_mapping_request import PatchedSAMLPropertyMappingRequest
    from authentik_client.models.patched_saml_provider_request import PatchedSAMLProviderRequest
    from authentik_client.models.patched_saml_source_property_mapping_request import PatchedSAMLSourcePropertyMappingRequest
    from authentik_client.models.patched_saml_source_request import PatchedSAMLSourceRequest
    from authentik_client.models.patched_scim_mapping_request import PatchedSCIMMappingRequest
    from authentik_client.models.patched_scim_provider_request import PatchedSCIMProviderRequest
    from authentik_client.models.patched_scim_source_group_request import PatchedSCIMSourceGroupRequest
    from authentik_client.models.patched_scim_source_property_mapping_request import PatchedSCIMSourcePropertyMappingRequest
    from authentik_client.models.patched_scim_source_request import PatchedSCIMSourceRequest
    from authentik_client.models.patched_scim_source_user_request import PatchedSCIMSourceUserRequest
    from authentik_client.models.patched_sms_device_request import PatchedSMSDeviceRequest
    from authentik_client.models.patched_ssf_provider_request import PatchedSSFProviderRequest
    from authentik_client.models.patched_schedule_request import PatchedScheduleRequest
    from authentik_client.models.patched_scope_mapping_request import PatchedScopeMappingRequest
    from authentik_client.models.patched_settings_request import PatchedSettingsRequest
    from authentik_client.models.patched_settings_request_flags import PatchedSettingsRequestFlags
    from authentik_client.models.patched_source_stage_request import PatchedSourceStageRequest
    from authentik_client.models.patched_static_device_request import PatchedStaticDeviceRequest
    from authentik_client.models.patched_totp_device_request import PatchedTOTPDeviceRequest
    from authentik_client.models.patched_telegram_source_property_mapping_request import PatchedTelegramSourcePropertyMappingRequest
    from authentik_client.models.patched_telegram_source_request import PatchedTelegramSourceRequest
    from authentik_client.models.patched_tenant_request import PatchedTenantRequest
    from authentik_client.models.patched_token_request import PatchedTokenRequest
    from authentik_client.models.patched_unique_password_policy_request import PatchedUniquePasswordPolicyRequest
    from authentik_client.models.patched_user_delete_stage_request import PatchedUserDeleteStageRequest
    from authentik_client.models.patched_user_kerberos_source_connection_request import PatchedUserKerberosSourceConnectionRequest
    from authentik_client.models.patched_user_ldap_source_connection_request import PatchedUserLDAPSourceConnectionRequest
    from authentik_client.models.patched_user_login_stage_request import PatchedUserLoginStageRequest
    from authentik_client.models.patched_user_logout_stage_request import PatchedUserLogoutStageRequest
    from authentik_client.models.patched_user_o_auth_source_connection_request import PatchedUserOAuthSourceConnectionRequest
    from authentik_client.models.patched_user_plex_source_connection_request import PatchedUserPlexSourceConnectionRequest
    from authentik_client.models.patched_user_request import PatchedUserRequest
    from authentik_client.models.patched_user_saml_source_connection_request import PatchedUserSAMLSourceConnectionRequest
    from authentik_client.models.patched_user_source_connection_request import PatchedUserSourceConnectionRequest
    from authentik_client.models.patched_user_telegram_source_connection_request import PatchedUserTelegramSourceConnectionRequest
    from authentik_client.models.patched_user_write_stage_request import PatchedUserWriteStageRequest
    from authentik_client.models.patched_web_authn_device_request import PatchedWebAuthnDeviceRequest
    from authentik_client.models.permission import Permission
    from authentik_client.models.permission_assign_request import PermissionAssignRequest
    from authentik_client.models.permission_assign_result import PermissionAssignResult
    from authentik_client.models.permission_request import PermissionRequest
    from authentik_client.models.plex_authentication_challenge import PlexAuthenticationChallenge
    from authentik_client.models.plex_authentication_challenge_response_request import PlexAuthenticationChallengeResponseRequest
    from authentik_client.models.plex_source import PlexSource
    from authentik_client.models.plex_source_property_mapping import PlexSourcePropertyMapping
    from authentik_client.models.plex_source_property_mapping_request import PlexSourcePropertyMappingRequest
    from authentik_client.models.plex_source_request import PlexSourceRequest
    from authentik_client.models.plex_token_redeem_request import PlexTokenRedeemRequest
    from authentik_client.models.policy import Policy
    from authentik_client.models.policy_binding import PolicyBinding
    from authentik_client.models.policy_binding_request import PolicyBindingRequest
    from authentik_client.models.policy_engine_mode import PolicyEngineMode
    from authentik_client.models.policy_request import PolicyRequest
    from authentik_client.models.policy_test_request import PolicyTestRequest
    from authentik_client.models.policy_test_result import PolicyTestResult
    from authentik_client.models.prompt import Prompt
    from authentik_client.models.prompt_challenge import PromptChallenge
    from authentik_client.models.prompt_challenge_response_request import PromptChallengeResponseRequest
    from authentik_client.models.prompt_request import PromptRequest
    from authentik_client.models.prompt_stage import PromptStage
    from authentik_client.models.prompt_stage_request import PromptStageRequest
    from authentik_client.models.prompt_type_enum import PromptTypeEnum
    from authentik_client.models.property_mapping import PropertyMapping
    from authentik_client.models.property_mapping_preview import PropertyMappingPreview
    from authentik_client.models.property_mapping_test_request import PropertyMappingTestRequest
    from authentik_client.models.property_mapping_test_result import PropertyMappingTestResult
    from authentik_client.models.protocol_enum import ProtocolEnum
    from authentik_client.models.provider import Provider
    from authentik_client.models.provider_enum import ProviderEnum
    from authentik_client.models.provider_model_enum import ProviderModelEnum
    from authentik_client.models.provider_request import ProviderRequest
    from authentik_client.models.provider_type_enum import ProviderTypeEnum
    from authentik_client.models.proxy_mode import ProxyMode
    from authentik_client.models.proxy_outpost_config import ProxyOutpostConfig
    from authentik_client.models.proxy_provider import ProxyProvider
    from authentik_client.models.proxy_provider_request import ProxyProviderRequest
    from authentik_client.models.rac_property_mapping import RACPropertyMapping
    from authentik_client.models.rac_property_mapping_request import RACPropertyMappingRequest
    from authentik_client.models.rac_provider import RACProvider
    from authentik_client.models.rac_provider_request import RACProviderRequest
    from authentik_client.models.radius_check_access import RadiusCheckAccess
    from authentik_client.models.radius_outpost_config import RadiusOutpostConfig
    from authentik_client.models.radius_provider import RadiusProvider
    from authentik_client.models.radius_provider_property_mapping import RadiusProviderPropertyMapping
    from authentik_client.models.radius_provider_property_mapping_request import RadiusProviderPropertyMappingRequest
    from authentik_client.models.radius_provider_request import RadiusProviderRequest
    from authentik_client.models.redirect_challenge import RedirectChallenge
    from authentik_client.models.redirect_challenge_response_request import RedirectChallengeResponseRequest
    from authentik_client.models.redirect_stage import RedirectStage
    from authentik_client.models.redirect_stage_mode_enum import RedirectStageModeEnum
    from authentik_client.models.redirect_stage_request import RedirectStageRequest
    from authentik_client.models.redirect_uri import RedirectURI
    from authentik_client.models.redirect_uri_request import RedirectURIRequest
    from authentik_client.models.reputation import Reputation
    from authentik_client.models.reputation_policy import ReputationPolicy
    from authentik_client.models.reputation_policy_request import ReputationPolicyRequest
    from authentik_client.models.resident_key_requirement_enum import ResidentKeyRequirementEnum
    from authentik_client.models.role import Role
    from authentik_client.models.role_assigned_object_permission import RoleAssignedObjectPermission
    from authentik_client.models.role_object_permission import RoleObjectPermission
    from authentik_client.models.role_request import RoleRequest
    from authentik_client.models.saml_metadata import SAMLMetadata
    from authentik_client.models.saml_name_id_policy_enum import SAMLNameIDPolicyEnum
    from authentik_client.models.saml_property_mapping import SAMLPropertyMapping
    from authentik_client.models.saml_property_mapping_request import SAMLPropertyMappingRequest
    from authentik_client.models.saml_provider import SAMLProvider
    from authentik_client.models.saml_provider_request import SAMLProviderRequest
    from authentik_client.models.saml_source import SAMLSource
    from authentik_client.models.saml_source_property_mapping import SAMLSourcePropertyMapping
    from authentik_client.models.saml_source_property_mapping_request import SAMLSourcePropertyMappingRequest
    from authentik_client.models.saml_source_request import SAMLSourceRequest
    from authentik_client.models.scim_authentication_mode_enum import SCIMAuthenticationModeEnum
    from authentik_client.models.scim_mapping import SCIMMapping
    from authentik_client.models.scim_mapping_request import SCIMMappingRequest
    from authentik_client.models.scim_provider import SCIMProvider
    from authentik_client.models.scim_provider_group import SCIMProviderGroup
    from authentik_client.models.scim_provider_group_request import SCIMProviderGroupRequest
    from authentik_client.models.scim_provider_request import SCIMProviderRequest
    from authentik_client.models.scim_provider_user import SCIMProviderUser
    from authentik_client.models.scim_provider_user_request import SCIMProviderUserRequest
    from authentik_client.models.scim_source import SCIMSource
    from authentik_client.models.scim_source_group import SCIMSourceGroup
    from authentik_client.models.scim_source_group_request import SCIMSourceGroupRequest
    from authentik_client.models.scim_source_property_mapping import SCIMSourcePropertyMapping
    from authentik_client.models.scim_source_property_mapping_request import SCIMSourcePropertyMappingRequest
    from authentik_client.models.scim_source_request import SCIMSourceRequest
    from authentik_client.models.scim_source_user import SCIMSourceUser
    from authentik_client.models.scim_source_user_request import SCIMSourceUserRequest
    from authentik_client.models.sms_device import SMSDevice
    from authentik_client.models.sms_device_request import SMSDeviceRequest
    from authentik_client.models.ssf_provider import SSFProvider
    from authentik_client.models.ssf_provider_request import SSFProviderRequest
    from authentik_client.models.ssf_stream import SSFStream
    from authentik_client.models.schedule import Schedule
    from authentik_client.models.schedule_request import ScheduleRequest
    from authentik_client.models.scope_mapping import ScopeMapping
    from authentik_client.models.scope_mapping_request import ScopeMappingRequest
    from authentik_client.models.selectable_stage import SelectableStage
    from authentik_client.models.service_connection import ServiceConnection
    from authentik_client.models.service_connection_request import ServiceConnectionRequest
    from authentik_client.models.service_connection_state import ServiceConnectionState
    from authentik_client.models.session_end_challenge import SessionEndChallenge
    from authentik_client.models.session_user import SessionUser
    from authentik_client.models.settings import Settings
    from authentik_client.models.settings_request import SettingsRequest
    from authentik_client.models.severity_enum import SeverityEnum
    from authentik_client.models.shell_challenge import ShellChallenge
    from authentik_client.models.signature_algorithm_enum import SignatureAlgorithmEnum
    from authentik_client.models.source import Source
    from authentik_client.models.source_request import SourceRequest
    from authentik_client.models.source_stage import SourceStage
    from authentik_client.models.source_stage_request import SourceStageRequest
    from authentik_client.models.source_type import SourceType
    from authentik_client.models.sp_binding_enum import SpBindingEnum
    from authentik_client.models.stage import Stage
    from authentik_client.models.stage_prompt import StagePrompt
    from authentik_client.models.stage_request import StageRequest
    from authentik_client.models.state_enum import StateEnum
    from authentik_client.models.static_device import StaticDevice
    from authentik_client.models.static_device_request import StaticDeviceRequest
    from authentik_client.models.static_device_token import StaticDeviceToken
    from authentik_client.models.sub_mode_enum import SubModeEnum
    from authentik_client.models.sync_object_model_enum import SyncObjectModelEnum
    from authentik_client.models.sync_object_request import SyncObjectRequest
    from authentik_client.models.sync_object_result import SyncObjectResult
    from authentik_client.models.sync_status import SyncStatus
    from authentik_client.models.system_info import SystemInfo
    from authentik_client.models.system_info_runtime import SystemInfoRuntime
    from authentik_client.models.totp_device import TOTPDevice
    from authentik_client.models.totp_device_request import TOTPDeviceRequest
    from authentik_client.models.task import Task
    from authentik_client.models.task_aggregated_status_enum import TaskAggregatedStatusEnum
    from authentik_client.models.telegram_challenge_response_request import TelegramChallengeResponseRequest
    from authentik_client.models.telegram_login_challenge import TelegramLoginChallenge
    from authentik_client.models.telegram_source import TelegramSource
    from authentik_client.models.telegram_source_property_mapping import TelegramSourcePropertyMapping
    from authentik_client.models.telegram_source_property_mapping_request import TelegramSourcePropertyMappingRequest
    from authentik_client.models.telegram_source_request import TelegramSourceRequest
    from authentik_client.models.tenant import Tenant
    from authentik_client.models.tenant_admin_group_request_request import TenantAdminGroupRequestRequest
    from authentik_client.models.tenant_recovery_key_request_request import TenantRecoveryKeyRequestRequest
    from authentik_client.models.tenant_recovery_key_response import TenantRecoveryKeyResponse
    from authentik_client.models.tenant_request import TenantRequest
    from authentik_client.models.token import Token
    from authentik_client.models.token_model import TokenModel
    from authentik_client.models.token_request import TokenRequest
    from authentik_client.models.token_set_key_request import TokenSetKeyRequest
    from authentik_client.models.token_view import TokenView
    from authentik_client.models.transaction_application_request import TransactionApplicationRequest
    from authentik_client.models.transaction_application_response import TransactionApplicationResponse
    from authentik_client.models.transaction_policy_binding_request import TransactionPolicyBindingRequest
    from authentik_client.models.type_create import TypeCreate
    from authentik_client.models.ui_theme_enum import UiThemeEnum
    from authentik_client.models.unique_password_policy import UniquePasswordPolicy
    from authentik_client.models.unique_password_policy_request import UniquePasswordPolicyRequest
    from authentik_client.models.used_by import UsedBy
    from authentik_client.models.used_by_action_enum import UsedByActionEnum
    from authentik_client.models.user import User
    from authentik_client.models.user_account_request import UserAccountRequest
    from authentik_client.models.user_assigned_object_permission import UserAssignedObjectPermission
    from authentik_client.models.user_attribute_enum import UserAttributeEnum
    from authentik_client.models.user_consent import UserConsent
    from authentik_client.models.user_creation_mode_enum import UserCreationModeEnum
    from authentik_client.models.user_delete_stage import UserDeleteStage
    from authentik_client.models.user_delete_stage_request import UserDeleteStageRequest
    from authentik_client.models.user_fields_enum import UserFieldsEnum
    from authentik_client.models.user_kerberos_source_connection import UserKerberosSourceConnection
    from authentik_client.models.user_kerberos_source_connection_request import UserKerberosSourceConnectionRequest
    from authentik_client.models.user_ldap_source_connection import UserLDAPSourceConnection
    from authentik_client.models.user_ldap_source_connection_request import UserLDAPSourceConnectionRequest
    from authentik_client.models.user_login_challenge import UserLoginChallenge
    from authentik_client.models.user_login_challenge_response_request import UserLoginChallengeResponseRequest
    from authentik_client.models.user_login_stage import UserLoginStage
    from authentik_client.models.user_login_stage_request import UserLoginStageRequest
    from authentik_client.models.user_logout_stage import UserLogoutStage
    from authentik_client.models.user_logout_stage_request import UserLogoutStageRequest
    from authentik_client.models.user_matching_mode_enum import UserMatchingModeEnum
    from authentik_client.models.user_o_auth_source_connection import UserOAuthSourceConnection
    from authentik_client.models.user_o_auth_source_connection_request import UserOAuthSourceConnectionRequest
    from authentik_client.models.user_object_permission import UserObjectPermission
    from authentik_client.models.user_password_set_request import UserPasswordSetRequest
    from authentik_client.models.user_path import UserPath
    from authentik_client.models.user_plex_source_connection import UserPlexSourceConnection
    from authentik_client.models.user_plex_source_connection_request import UserPlexSourceConnectionRequest
    from authentik_client.models.user_request import UserRequest
    from authentik_client.models.user_saml_source_connection import UserSAMLSourceConnection
    from authentik_client.models.user_saml_source_connection_request import UserSAMLSourceConnectionRequest
    from authentik_client.models.user_self import UserSelf
    from authentik_client.models.user_self_groups import UserSelfGroups
    from authentik_client.models.user_service_account_request import UserServiceAccountRequest
    from authentik_client.models.user_service_account_response import UserServiceAccountResponse
    from authentik_client.models.user_setting import UserSetting
    from authentik_client.models.user_source_connection import UserSourceConnection
    from authentik_client.models.user_source_connection_request import UserSourceConnectionRequest
    from authentik_client.models.user_telegram_source_connection import UserTelegramSourceConnection
    from authentik_client.models.user_telegram_source_connection_request import UserTelegramSourceConnectionRequest
    from authentik_client.models.user_type_enum import UserTypeEnum
    from authentik_client.models.user_verification_enum import UserVerificationEnum
    from authentik_client.models.user_write_stage import UserWriteStage
    from authentik_client.models.user_write_stage_request import UserWriteStageRequest
    from authentik_client.models.validation_error import ValidationError
    from authentik_client.models.version import Version
    from authentik_client.models.version_history import VersionHistory
    from authentik_client.models.web_authn_device import WebAuthnDevice
    from authentik_client.models.web_authn_device_request import WebAuthnDeviceRequest
    from authentik_client.models.web_authn_device_type import WebAuthnDeviceType
    from authentik_client.models.worker import Worker
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import models into model package
from authentik_client.models.access_denied_challenge import AccessDeniedChallenge
from authentik_client.models.alg_enum import AlgEnum
from authentik_client.models.app import App
from authentik_client.models.app_enum import AppEnum
from authentik_client.models.apple_challenge_response_request import AppleChallengeResponseRequest
from authentik_client.models.apple_login_challenge import AppleLoginChallenge
from authentik_client.models.application import Application
from authentik_client.models.application_entitlement import ApplicationEntitlement
from authentik_client.models.application_entitlement_request import ApplicationEntitlementRequest
from authentik_client.models.application_request import ApplicationRequest
from authentik_client.models.auth_type_enum import AuthTypeEnum
from authentik_client.models.authenticated_session import AuthenticatedSession
from authentik_client.models.authenticated_session_asn import AuthenticatedSessionAsn
from authentik_client.models.authenticated_session_geo_ip import AuthenticatedSessionGeoIp
from authentik_client.models.authenticated_session_user_agent import AuthenticatedSessionUserAgent
from authentik_client.models.authenticated_session_user_agent_device import AuthenticatedSessionUserAgentDevice
from authentik_client.models.authenticated_session_user_agent_os import AuthenticatedSessionUserAgentOs
from authentik_client.models.authenticated_session_user_agent_user_agent import AuthenticatedSessionUserAgentUserAgent
from authentik_client.models.authentication_enum import AuthenticationEnum
from authentik_client.models.authenticator_attachment_enum import AuthenticatorAttachmentEnum
from authentik_client.models.authenticator_duo_challenge import AuthenticatorDuoChallenge
from authentik_client.models.authenticator_duo_challenge_response_request import AuthenticatorDuoChallengeResponseRequest
from authentik_client.models.authenticator_duo_stage import AuthenticatorDuoStage
from authentik_client.models.authenticator_duo_stage_device_import_response import AuthenticatorDuoStageDeviceImportResponse
from authentik_client.models.authenticator_duo_stage_manual_device_import_request import AuthenticatorDuoStageManualDeviceImportRequest
from authentik_client.models.authenticator_duo_stage_request import AuthenticatorDuoStageRequest
from authentik_client.models.authenticator_email_challenge import AuthenticatorEmailChallenge
from authentik_client.models.authenticator_email_challenge_response_request import AuthenticatorEmailChallengeResponseRequest
from authentik_client.models.authenticator_email_stage import AuthenticatorEmailStage
from authentik_client.models.authenticator_email_stage_request import AuthenticatorEmailStageRequest
from authentik_client.models.authenticator_endpoint_gdtc_stage import AuthenticatorEndpointGDTCStage
from authentik_client.models.authenticator_endpoint_gdtc_stage_request import AuthenticatorEndpointGDTCStageRequest
from authentik_client.models.authenticator_sms_challenge import AuthenticatorSMSChallenge
from authentik_client.models.authenticator_sms_challenge_response_request import AuthenticatorSMSChallengeResponseRequest
from authentik_client.models.authenticator_sms_stage import AuthenticatorSMSStage
from authentik_client.models.authenticator_sms_stage_request import AuthenticatorSMSStageRequest
from authentik_client.models.authenticator_static_challenge import AuthenticatorStaticChallenge
from authentik_client.models.authenticator_static_challenge_response_request import AuthenticatorStaticChallengeResponseRequest
from authentik_client.models.authenticator_static_stage import AuthenticatorStaticStage
from authentik_client.models.authenticator_static_stage_request import AuthenticatorStaticStageRequest
from authentik_client.models.authenticator_totp_challenge import AuthenticatorTOTPChallenge
from authentik_client.models.authenticator_totp_challenge_response_request import AuthenticatorTOTPChallengeResponseRequest
from authentik_client.models.authenticator_totp_stage import AuthenticatorTOTPStage
from authentik_client.models.authenticator_totp_stage_request import AuthenticatorTOTPStageRequest
from authentik_client.models.authenticator_validate_stage import AuthenticatorValidateStage
from authentik_client.models.authenticator_validate_stage_request import AuthenticatorValidateStageRequest
from authentik_client.models.authenticator_validation_challenge import AuthenticatorValidationChallenge
from authentik_client.models.authenticator_validation_challenge_response_request import AuthenticatorValidationChallengeResponseRequest
from authentik_client.models.authenticator_web_authn_challenge import AuthenticatorWebAuthnChallenge
from authentik_client.models.authenticator_web_authn_challenge_response_request import AuthenticatorWebAuthnChallengeResponseRequest
from authentik_client.models.authenticator_web_authn_stage import AuthenticatorWebAuthnStage
from authentik_client.models.authenticator_web_authn_stage_request import AuthenticatorWebAuthnStageRequest
from authentik_client.models.authorization_code_auth_method_enum import AuthorizationCodeAuthMethodEnum
from authentik_client.models.auto_submit_challenge_response_request import AutoSubmitChallengeResponseRequest
from authentik_client.models.autosubmit_challenge import AutosubmitChallenge
from authentik_client.models.backends_enum import BackendsEnum
from authentik_client.models.binding_type_enum import BindingTypeEnum
from authentik_client.models.blueprint_file import BlueprintFile
from authentik_client.models.blueprint_instance import BlueprintInstance
from authentik_client.models.blueprint_instance_request import BlueprintInstanceRequest
from authentik_client.models.blueprint_instance_status_enum import BlueprintInstanceStatusEnum
from authentik_client.models.brand import Brand
from authentik_client.models.brand_request import BrandRequest
from authentik_client.models.cache import Cache
from authentik_client.models.capabilities_enum import CapabilitiesEnum
from authentik_client.models.captcha_challenge import CaptchaChallenge
from authentik_client.models.captcha_challenge_response_request import CaptchaChallengeResponseRequest
from authentik_client.models.captcha_stage import CaptchaStage
from authentik_client.models.captcha_stage_request import CaptchaStageRequest
from authentik_client.models.cert_attribute_enum import CertAttributeEnum
from authentik_client.models.certificate_data import CertificateData
from authentik_client.models.certificate_generation_request import CertificateGenerationRequest
from authentik_client.models.certificate_key_pair import CertificateKeyPair
from authentik_client.models.certificate_key_pair_request import CertificateKeyPairRequest
from authentik_client.models.challenge_types import ChallengeTypes
from authentik_client.models.client_type_enum import ClientTypeEnum
from authentik_client.models.compatibility_mode_enum import CompatibilityModeEnum
from authentik_client.models.config import Config
from authentik_client.models.connection_token import ConnectionToken
from authentik_client.models.connection_token_request import ConnectionTokenRequest
from authentik_client.models.consent_challenge import ConsentChallenge
from authentik_client.models.consent_challenge_response_request import ConsentChallengeResponseRequest
from authentik_client.models.consent_permission import ConsentPermission
from authentik_client.models.consent_stage import ConsentStage
from authentik_client.models.consent_stage_mode_enum import ConsentStageModeEnum
from authentik_client.models.consent_stage_request import ConsentStageRequest
from authentik_client.models.contextual_flow_info import ContextualFlowInfo
from authentik_client.models.contextual_flow_info_layout_enum import ContextualFlowInfoLayoutEnum
from authentik_client.models.country_code_enum import CountryCodeEnum
from authentik_client.models.current_brand import CurrentBrand
from authentik_client.models.current_brand_flags import CurrentBrandFlags
from authentik_client.models.delivery_method_enum import DeliveryMethodEnum
from authentik_client.models.denied_action_enum import DeniedActionEnum
from authentik_client.models.deny_stage import DenyStage
from authentik_client.models.deny_stage_request import DenyStageRequest
from authentik_client.models.detailed_country import DetailedCountry
from authentik_client.models.detailed_country_field import DetailedCountryField
from authentik_client.models.device import Device
from authentik_client.models.device_challenge import DeviceChallenge
from authentik_client.models.device_challenge_request import DeviceChallengeRequest
from authentik_client.models.device_classes_enum import DeviceClassesEnum
from authentik_client.models.digest_algorithm_enum import DigestAlgorithmEnum
from authentik_client.models.digits_enum import DigitsEnum
from authentik_client.models.docker_service_connection import DockerServiceConnection
from authentik_client.models.docker_service_connection_request import DockerServiceConnectionRequest
from authentik_client.models.domain import Domain
from authentik_client.models.domain_request import DomainRequest
from authentik_client.models.dummy_challenge import DummyChallenge
from authentik_client.models.dummy_challenge_response_request import DummyChallengeResponseRequest
from authentik_client.models.dummy_policy import DummyPolicy
from authentik_client.models.dummy_policy_request import DummyPolicyRequest
from authentik_client.models.dummy_stage import DummyStage
from authentik_client.models.dummy_stage_request import DummyStageRequest
from authentik_client.models.duo_device import DuoDevice
from authentik_client.models.duo_device_enrollment_status import DuoDeviceEnrollmentStatus
from authentik_client.models.duo_device_request import DuoDeviceRequest
from authentik_client.models.duo_response_enum import DuoResponseEnum
from authentik_client.models.email_challenge import EmailChallenge
from authentik_client.models.email_challenge_response_request import EmailChallengeResponseRequest
from authentik_client.models.email_device import EmailDevice
from authentik_client.models.email_device_request import EmailDeviceRequest
from authentik_client.models.email_stage import EmailStage
from authentik_client.models.email_stage_request import EmailStageRequest
from authentik_client.models.endpoint import Endpoint
from authentik_client.models.endpoint_auth_mode_enum import EndpointAuthModeEnum
from authentik_client.models.endpoint_device import EndpointDevice
from authentik_client.models.endpoint_device_request import EndpointDeviceRequest
from authentik_client.models.endpoint_request import EndpointRequest
from authentik_client.models.error_detail import ErrorDetail
from authentik_client.models.error_reporting_config import ErrorReportingConfig
from authentik_client.models.event import Event
from authentik_client.models.event_actions import EventActions
from authentik_client.models.event_matcher_policy import EventMatcherPolicy
from authentik_client.models.event_matcher_policy_request import EventMatcherPolicyRequest
from authentik_client.models.event_request import EventRequest
from authentik_client.models.event_top_per_user import EventTopPerUser
from authentik_client.models.event_volume import EventVolume
from authentik_client.models.events_requested_enum import EventsRequestedEnum
from authentik_client.models.expiring_base_grant_model import ExpiringBaseGrantModel
from authentik_client.models.expression_policy import ExpressionPolicy
from authentik_client.models.expression_policy_request import ExpressionPolicyRequest
from authentik_client.models.extra_role_object_permission import ExtraRoleObjectPermission
from authentik_client.models.extra_role_object_permission_request import ExtraRoleObjectPermissionRequest
from authentik_client.models.extra_user_object_permission import ExtraUserObjectPermission
from authentik_client.models.extra_user_object_permission_request import ExtraUserObjectPermissionRequest
from authentik_client.models.file_path_request import FilePathRequest
from authentik_client.models.flow import Flow
from authentik_client.models.flow_challenge_response_request import FlowChallengeResponseRequest
from authentik_client.models.flow_designation_enum import FlowDesignationEnum
from authentik_client.models.flow_diagram import FlowDiagram
from authentik_client.models.flow_error_challenge import FlowErrorChallenge
from authentik_client.models.flow_import_result import FlowImportResult
from authentik_client.models.flow_inspection import FlowInspection
from authentik_client.models.flow_inspector_plan import FlowInspectorPlan
from authentik_client.models.flow_layout_enum import FlowLayoutEnum
from authentik_client.models.flow_request import FlowRequest
from authentik_client.models.flow_set import FlowSet
from authentik_client.models.flow_set_request import FlowSetRequest
from authentik_client.models.flow_stage_binding import FlowStageBinding
from authentik_client.models.flow_stage_binding_request import FlowStageBindingRequest
from authentik_client.models.footer_link import FooterLink
from authentik_client.models.frame_challenge import FrameChallenge
from authentik_client.models.frame_challenge_response_request import FrameChallengeResponseRequest
from authentik_client.models.generic_error import GenericError
from authentik_client.models.geo_ip_policy import GeoIPPolicy
from authentik_client.models.geo_ip_policy_request import GeoIPPolicyRequest
from authentik_client.models.geoip_binding_enum import GeoipBindingEnum
from authentik_client.models.google_workspace_provider import GoogleWorkspaceProvider
from authentik_client.models.google_workspace_provider_group import GoogleWorkspaceProviderGroup
from authentik_client.models.google_workspace_provider_group_request import GoogleWorkspaceProviderGroupRequest
from authentik_client.models.google_workspace_provider_mapping import GoogleWorkspaceProviderMapping
from authentik_client.models.google_workspace_provider_mapping_request import GoogleWorkspaceProviderMappingRequest
from authentik_client.models.google_workspace_provider_request import GoogleWorkspaceProviderRequest
from authentik_client.models.google_workspace_provider_user import GoogleWorkspaceProviderUser
from authentik_client.models.google_workspace_provider_user_request import GoogleWorkspaceProviderUserRequest
from authentik_client.models.group import Group
from authentik_client.models.group_child import GroupChild
from authentik_client.models.group_kerberos_source_connection import GroupKerberosSourceConnection
from authentik_client.models.group_kerberos_source_connection_request import GroupKerberosSourceConnectionRequest
from authentik_client.models.group_ldap_source_connection import GroupLDAPSourceConnection
from authentik_client.models.group_ldap_source_connection_request import GroupLDAPSourceConnectionRequest
from authentik_client.models.group_matching_mode_enum import GroupMatchingModeEnum
from authentik_client.models.group_o_auth_source_connection import GroupOAuthSourceConnection
from authentik_client.models.group_o_auth_source_connection_request import GroupOAuthSourceConnectionRequest
from authentik_client.models.group_plex_source_connection import GroupPlexSourceConnection
from authentik_client.models.group_plex_source_connection_request import GroupPlexSourceConnectionRequest
from authentik_client.models.group_request import GroupRequest
from authentik_client.models.group_saml_source_connection import GroupSAMLSourceConnection
from authentik_client.models.group_saml_source_connection_request import GroupSAMLSourceConnectionRequest
from authentik_client.models.group_source_connection import GroupSourceConnection
from authentik_client.models.group_source_connection_request import GroupSourceConnectionRequest
from authentik_client.models.group_telegram_source_connection import GroupTelegramSourceConnection
from authentik_client.models.group_telegram_source_connection_request import GroupTelegramSourceConnectionRequest
from authentik_client.models.identification_challenge import IdentificationChallenge
from authentik_client.models.identification_challenge_response_request import IdentificationChallengeResponseRequest
from authentik_client.models.identification_stage import IdentificationStage
from authentik_client.models.identification_stage_request import IdentificationStageRequest
from authentik_client.models.impersonation_request import ImpersonationRequest
from authentik_client.models.initial_permissions import InitialPermissions
from authentik_client.models.initial_permissions_mode_enum import InitialPermissionsModeEnum
from authentik_client.models.initial_permissions_request import InitialPermissionsRequest
from authentik_client.models.install_id import InstallID
from authentik_client.models.intent_enum import IntentEnum
from authentik_client.models.invalid_response_action_enum import InvalidResponseActionEnum
from authentik_client.models.invitation import Invitation
from authentik_client.models.invitation_request import InvitationRequest
from authentik_client.models.invitation_stage import InvitationStage
from authentik_client.models.invitation_stage_request import InvitationStageRequest
from authentik_client.models.issuer_mode_enum import IssuerModeEnum
from authentik_client.models.kadmin_type_enum import KadminTypeEnum
from authentik_client.models.kerberos_source import KerberosSource
from authentik_client.models.kerberos_source_property_mapping import KerberosSourcePropertyMapping
from authentik_client.models.kerberos_source_property_mapping_request import KerberosSourcePropertyMappingRequest
from authentik_client.models.kerberos_source_request import KerberosSourceRequest
from authentik_client.models.kubernetes_service_connection import KubernetesServiceConnection
from authentik_client.models.kubernetes_service_connection_request import KubernetesServiceConnectionRequest
from authentik_client.models.ldapapi_access_mode import LDAPAPIAccessMode
from authentik_client.models.ldap_check_access import LDAPCheckAccess
from authentik_client.models.ldap_debug import LDAPDebug
from authentik_client.models.ldap_outpost_config import LDAPOutpostConfig
from authentik_client.models.ldap_provider import LDAPProvider
from authentik_client.models.ldap_provider_request import LDAPProviderRequest
from authentik_client.models.ldap_source import LDAPSource
from authentik_client.models.ldap_source_property_mapping import LDAPSourcePropertyMapping
from authentik_client.models.ldap_source_property_mapping_request import LDAPSourcePropertyMappingRequest
from authentik_client.models.ldap_source_request import LDAPSourceRequest
from authentik_client.models.last_task_status_enum import LastTaskStatusEnum
from authentik_client.models.license import License
from authentik_client.models.license_flags_enum import LicenseFlagsEnum
from authentik_client.models.license_forecast import LicenseForecast
from authentik_client.models.license_request import LicenseRequest
from authentik_client.models.license_summary import LicenseSummary
from authentik_client.models.license_summary_status_enum import LicenseSummaryStatusEnum
from authentik_client.models.link import Link
from authentik_client.models.log_event import LogEvent
from authentik_client.models.log_level_enum import LogLevelEnum
from authentik_client.models.login_challenge_types import LoginChallengeTypes
from authentik_client.models.login_source import LoginSource
from authentik_client.models.matching_mode_enum import MatchingModeEnum
from authentik_client.models.metadata import Metadata
from authentik_client.models.microsoft_entra_provider import MicrosoftEntraProvider
from authentik_client.models.microsoft_entra_provider_group import MicrosoftEntraProviderGroup
from authentik_client.models.microsoft_entra_provider_group_request import MicrosoftEntraProviderGroupRequest
from authentik_client.models.microsoft_entra_provider_mapping import MicrosoftEntraProviderMapping
from authentik_client.models.microsoft_entra_provider_mapping_request import MicrosoftEntraProviderMappingRequest
from authentik_client.models.microsoft_entra_provider_request import MicrosoftEntraProviderRequest
from authentik_client.models.microsoft_entra_provider_user import MicrosoftEntraProviderUser
from authentik_client.models.microsoft_entra_provider_user_request import MicrosoftEntraProviderUserRequest
from authentik_client.models.model_enum import ModelEnum
from authentik_client.models.model_request import ModelRequest
from authentik_client.models.mutual_tls_stage import MutualTLSStage
from authentik_client.models.mutual_tls_stage_mode_enum import MutualTLSStageModeEnum
from authentik_client.models.mutual_tls_stage_request import MutualTLSStageRequest
from authentik_client.models.network_binding_enum import NetworkBindingEnum
from authentik_client.models.not_configured_action_enum import NotConfiguredActionEnum
from authentik_client.models.notification import Notification
from authentik_client.models.notification_request import NotificationRequest
from authentik_client.models.notification_rule import NotificationRule
from authentik_client.models.notification_rule_request import NotificationRuleRequest
from authentik_client.models.notification_transport import NotificationTransport
from authentik_client.models.notification_transport_mode_enum import NotificationTransportModeEnum
from authentik_client.models.notification_transport_request import NotificationTransportRequest
from authentik_client.models.notification_transport_test import NotificationTransportTest
from authentik_client.models.notification_webhook_mapping import NotificationWebhookMapping
from authentik_client.models.notification_webhook_mapping_request import NotificationWebhookMappingRequest
from authentik_client.models.o_auth2_provider import OAuth2Provider
from authentik_client.models.o_auth2_provider_request import OAuth2ProviderRequest
from authentik_client.models.o_auth2_provider_setup_urls import OAuth2ProviderSetupURLs
from authentik_client.models.o_auth_device_code_challenge import OAuthDeviceCodeChallenge
from authentik_client.models.o_auth_device_code_challenge_response_request import OAuthDeviceCodeChallengeResponseRequest
from authentik_client.models.o_auth_device_code_finish_challenge import OAuthDeviceCodeFinishChallenge
from authentik_client.models.o_auth_device_code_finish_challenge_response_request import OAuthDeviceCodeFinishChallengeResponseRequest
from authentik_client.models.o_auth_source import OAuthSource
from authentik_client.models.o_auth_source_property_mapping import OAuthSourcePropertyMapping
from authentik_client.models.o_auth_source_property_mapping_request import OAuthSourcePropertyMappingRequest
from authentik_client.models.o_auth_source_request import OAuthSourceRequest
from authentik_client.models.open_id_connect_configuration import OpenIDConnectConfiguration
from authentik_client.models.outgoing_sync_delete_action import OutgoingSyncDeleteAction
from authentik_client.models.outpost import Outpost
from authentik_client.models.outpost_default_config import OutpostDefaultConfig
from authentik_client.models.outpost_health import OutpostHealth
from authentik_client.models.outpost_request import OutpostRequest
from authentik_client.models.outpost_type_enum import OutpostTypeEnum
from authentik_client.models.paginated_application_entitlement_list import PaginatedApplicationEntitlementList
from authentik_client.models.paginated_application_list import PaginatedApplicationList
from authentik_client.models.paginated_authenticated_session_list import PaginatedAuthenticatedSessionList
from authentik_client.models.paginated_authenticator_duo_stage_list import PaginatedAuthenticatorDuoStageList
from authentik_client.models.paginated_authenticator_email_stage_list import PaginatedAuthenticatorEmailStageList
from authentik_client.models.paginated_authenticator_endpoint_gdtc_stage_list import PaginatedAuthenticatorEndpointGDTCStageList
from authentik_client.models.paginated_authenticator_sms_stage_list import PaginatedAuthenticatorSMSStageList
from authentik_client.models.paginated_authenticator_static_stage_list import PaginatedAuthenticatorStaticStageList
from authentik_client.models.paginated_authenticator_totp_stage_list import PaginatedAuthenticatorTOTPStageList
from authentik_client.models.paginated_authenticator_validate_stage_list import PaginatedAuthenticatorValidateStageList
from authentik_client.models.paginated_authenticator_web_authn_stage_list import PaginatedAuthenticatorWebAuthnStageList
from authentik_client.models.paginated_blueprint_instance_list import PaginatedBlueprintInstanceList
from authentik_client.models.paginated_brand_list import PaginatedBrandList
from authentik_client.models.paginated_captcha_stage_list import PaginatedCaptchaStageList
from authentik_client.models.paginated_certificate_key_pair_list import PaginatedCertificateKeyPairList
from authentik_client.models.paginated_connection_token_list import PaginatedConnectionTokenList
from authentik_client.models.paginated_consent_stage_list import PaginatedConsentStageList
from authentik_client.models.paginated_deny_stage_list import PaginatedDenyStageList
from authentik_client.models.paginated_docker_service_connection_list import PaginatedDockerServiceConnectionList
from authentik_client.models.paginated_domain_list import PaginatedDomainList
from authentik_client.models.paginated_dummy_policy_list import PaginatedDummyPolicyList
from authentik_client.models.paginated_dummy_stage_list import PaginatedDummyStageList
from authentik_client.models.paginated_duo_device_list import PaginatedDuoDeviceList
from authentik_client.models.paginated_email_device_list import PaginatedEmailDeviceList
from authentik_client.models.paginated_email_stage_list import PaginatedEmailStageList
from authentik_client.models.paginated_endpoint_device_list import PaginatedEndpointDeviceList
from authentik_client.models.paginated_endpoint_list import PaginatedEndpointList
from authentik_client.models.paginated_event_list import PaginatedEventList
from authentik_client.models.paginated_event_matcher_policy_list import PaginatedEventMatcherPolicyList
from authentik_client.models.paginated_expiring_base_grant_model_list import PaginatedExpiringBaseGrantModelList
from authentik_client.models.paginated_expression_policy_list import PaginatedExpressionPolicyList
from authentik_client.models.paginated_extra_role_object_permission_list import PaginatedExtraRoleObjectPermissionList
from authentik_client.models.paginated_extra_user_object_permission_list import PaginatedExtraUserObjectPermissionList
from authentik_client.models.paginated_flow_list import PaginatedFlowList
from authentik_client.models.paginated_flow_stage_binding_list import PaginatedFlowStageBindingList
from authentik_client.models.paginated_geo_ip_policy_list import PaginatedGeoIPPolicyList
from authentik_client.models.paginated_google_workspace_provider_group_list import PaginatedGoogleWorkspaceProviderGroupList
from authentik_client.models.paginated_google_workspace_provider_list import PaginatedGoogleWorkspaceProviderList
from authentik_client.models.paginated_google_workspace_provider_mapping_list import PaginatedGoogleWorkspaceProviderMappingList
from authentik_client.models.paginated_google_workspace_provider_user_list import PaginatedGoogleWorkspaceProviderUserList
from authentik_client.models.paginated_group_kerberos_source_connection_list import PaginatedGroupKerberosSourceConnectionList
from authentik_client.models.paginated_group_ldap_source_connection_list import PaginatedGroupLDAPSourceConnectionList
from authentik_client.models.paginated_group_list import PaginatedGroupList
from authentik_client.models.paginated_group_o_auth_source_connection_list import PaginatedGroupOAuthSourceConnectionList
from authentik_client.models.paginated_group_plex_source_connection_list import PaginatedGroupPlexSourceConnectionList
from authentik_client.models.paginated_group_saml_source_connection_list import PaginatedGroupSAMLSourceConnectionList
from authentik_client.models.paginated_group_source_connection_list import PaginatedGroupSourceConnectionList
from authentik_client.models.paginated_group_telegram_source_connection_list import PaginatedGroupTelegramSourceConnectionList
from authentik_client.models.paginated_identification_stage_list import PaginatedIdentificationStageList
from authentik_client.models.paginated_initial_permissions_list import PaginatedInitialPermissionsList
from authentik_client.models.paginated_invitation_list import PaginatedInvitationList
from authentik_client.models.paginated_invitation_stage_list import PaginatedInvitationStageList
from authentik_client.models.paginated_kerberos_source_list import PaginatedKerberosSourceList
from authentik_client.models.paginated_kerberos_source_property_mapping_list import PaginatedKerberosSourcePropertyMappingList
from authentik_client.models.paginated_kubernetes_service_connection_list import PaginatedKubernetesServiceConnectionList
from authentik_client.models.paginated_ldap_outpost_config_list import PaginatedLDAPOutpostConfigList
from authentik_client.models.paginated_ldap_provider_list import PaginatedLDAPProviderList
from authentik_client.models.paginated_ldap_source_list import PaginatedLDAPSourceList
from authentik_client.models.paginated_ldap_source_property_mapping_list import PaginatedLDAPSourcePropertyMappingList
from authentik_client.models.paginated_license_list import PaginatedLicenseList
from authentik_client.models.paginated_microsoft_entra_provider_group_list import PaginatedMicrosoftEntraProviderGroupList
from authentik_client.models.paginated_microsoft_entra_provider_list import PaginatedMicrosoftEntraProviderList
from authentik_client.models.paginated_microsoft_entra_provider_mapping_list import PaginatedMicrosoftEntraProviderMappingList
from authentik_client.models.paginated_microsoft_entra_provider_user_list import PaginatedMicrosoftEntraProviderUserList
from authentik_client.models.paginated_mutual_tls_stage_list import PaginatedMutualTLSStageList
from authentik_client.models.paginated_notification_list import PaginatedNotificationList
from authentik_client.models.paginated_notification_rule_list import PaginatedNotificationRuleList
from authentik_client.models.paginated_notification_transport_list import PaginatedNotificationTransportList
from authentik_client.models.paginated_notification_webhook_mapping_list import PaginatedNotificationWebhookMappingList
from authentik_client.models.paginated_o_auth2_provider_list import PaginatedOAuth2ProviderList
from authentik_client.models.paginated_o_auth_source_list import PaginatedOAuthSourceList
from authentik_client.models.paginated_o_auth_source_property_mapping_list import PaginatedOAuthSourcePropertyMappingList
from authentik_client.models.paginated_outpost_list import PaginatedOutpostList
from authentik_client.models.paginated_password_expiry_policy_list import PaginatedPasswordExpiryPolicyList
from authentik_client.models.paginated_password_policy_list import PaginatedPasswordPolicyList
from authentik_client.models.paginated_password_stage_list import PaginatedPasswordStageList
from authentik_client.models.paginated_permission_list import PaginatedPermissionList
from authentik_client.models.paginated_plex_source_list import PaginatedPlexSourceList
from authentik_client.models.paginated_plex_source_property_mapping_list import PaginatedPlexSourcePropertyMappingList
from authentik_client.models.paginated_policy_binding_list import PaginatedPolicyBindingList
from authentik_client.models.paginated_policy_list import PaginatedPolicyList
from authentik_client.models.paginated_prompt_list import PaginatedPromptList
from authentik_client.models.paginated_prompt_stage_list import PaginatedPromptStageList
from authentik_client.models.paginated_property_mapping_list import PaginatedPropertyMappingList
from authentik_client.models.paginated_provider_list import PaginatedProviderList
from authentik_client.models.paginated_proxy_outpost_config_list import PaginatedProxyOutpostConfigList
from authentik_client.models.paginated_proxy_provider_list import PaginatedProxyProviderList
from authentik_client.models.paginated_rac_property_mapping_list import PaginatedRACPropertyMappingList
from authentik_client.models.paginated_rac_provider_list import PaginatedRACProviderList
from authentik_client.models.paginated_radius_outpost_config_list import PaginatedRadiusOutpostConfigList
from authentik_client.models.paginated_radius_provider_list import PaginatedRadiusProviderList
from authentik_client.models.paginated_radius_provider_property_mapping_list import PaginatedRadiusProviderPropertyMappingList
from authentik_client.models.paginated_redirect_stage_list import PaginatedRedirectStageList
from authentik_client.models.paginated_reputation_list import PaginatedReputationList
from authentik_client.models.paginated_reputation_policy_list import PaginatedReputationPolicyList
from authentik_client.models.paginated_role_assigned_object_permission_list import PaginatedRoleAssignedObjectPermissionList
from authentik_client.models.paginated_role_list import PaginatedRoleList
from authentik_client.models.paginated_saml_property_mapping_list import PaginatedSAMLPropertyMappingList
from authentik_client.models.paginated_saml_provider_list import PaginatedSAMLProviderList
from authentik_client.models.paginated_saml_source_list import PaginatedSAMLSourceList
from authentik_client.models.paginated_saml_source_property_mapping_list import PaginatedSAMLSourcePropertyMappingList
from authentik_client.models.paginated_scim_mapping_list import PaginatedSCIMMappingList
from authentik_client.models.paginated_scim_provider_group_list import PaginatedSCIMProviderGroupList
from authentik_client.models.paginated_scim_provider_list import PaginatedSCIMProviderList
from authentik_client.models.paginated_scim_provider_user_list import PaginatedSCIMProviderUserList
from authentik_client.models.paginated_scim_source_group_list import PaginatedSCIMSourceGroupList
from authentik_client.models.paginated_scim_source_list import PaginatedSCIMSourceList
from authentik_client.models.paginated_scim_source_property_mapping_list import PaginatedSCIMSourcePropertyMappingList
from authentik_client.models.paginated_scim_source_user_list import PaginatedSCIMSourceUserList
from authentik_client.models.paginated_sms_device_list import PaginatedSMSDeviceList
from authentik_client.models.paginated_ssf_provider_list import PaginatedSSFProviderList
from authentik_client.models.paginated_ssf_stream_list import PaginatedSSFStreamList
from authentik_client.models.paginated_schedule_list import PaginatedScheduleList
from authentik_client.models.paginated_scope_mapping_list import PaginatedScopeMappingList
from authentik_client.models.paginated_service_connection_list import PaginatedServiceConnectionList
from authentik_client.models.paginated_source_list import PaginatedSourceList
from authentik_client.models.paginated_source_stage_list import PaginatedSourceStageList
from authentik_client.models.paginated_stage_list import PaginatedStageList
from authentik_client.models.paginated_static_device_list import PaginatedStaticDeviceList
from authentik_client.models.paginated_totp_device_list import PaginatedTOTPDeviceList
from authentik_client.models.paginated_task_list import PaginatedTaskList
from authentik_client.models.paginated_telegram_source_list import PaginatedTelegramSourceList
from authentik_client.models.paginated_telegram_source_property_mapping_list import PaginatedTelegramSourcePropertyMappingList
from authentik_client.models.paginated_tenant_list import PaginatedTenantList
from authentik_client.models.paginated_token_list import PaginatedTokenList
from authentik_client.models.paginated_token_model_list import PaginatedTokenModelList
from authentik_client.models.paginated_unique_password_policy_list import PaginatedUniquePasswordPolicyList
from authentik_client.models.paginated_user_assigned_object_permission_list import PaginatedUserAssignedObjectPermissionList
from authentik_client.models.paginated_user_consent_list import PaginatedUserConsentList
from authentik_client.models.paginated_user_delete_stage_list import PaginatedUserDeleteStageList
from authentik_client.models.paginated_user_kerberos_source_connection_list import PaginatedUserKerberosSourceConnectionList
from authentik_client.models.paginated_user_ldap_source_connection_list import PaginatedUserLDAPSourceConnectionList
from authentik_client.models.paginated_user_list import PaginatedUserList
from authentik_client.models.paginated_user_login_stage_list import PaginatedUserLoginStageList
from authentik_client.models.paginated_user_logout_stage_list import PaginatedUserLogoutStageList
from authentik_client.models.paginated_user_o_auth_source_connection_list import PaginatedUserOAuthSourceConnectionList
from authentik_client.models.paginated_user_plex_source_connection_list import PaginatedUserPlexSourceConnectionList
from authentik_client.models.paginated_user_saml_source_connection_list import PaginatedUserSAMLSourceConnectionList
from authentik_client.models.paginated_user_source_connection_list import PaginatedUserSourceConnectionList
from authentik_client.models.paginated_user_telegram_source_connection_list import PaginatedUserTelegramSourceConnectionList
from authentik_client.models.paginated_user_write_stage_list import PaginatedUserWriteStageList
from authentik_client.models.paginated_web_authn_device_list import PaginatedWebAuthnDeviceList
from authentik_client.models.paginated_web_authn_device_type_list import PaginatedWebAuthnDeviceTypeList
from authentik_client.models.pagination import Pagination
from authentik_client.models.partial_group import PartialGroup
from authentik_client.models.partial_user import PartialUser
from authentik_client.models.password_challenge import PasswordChallenge
from authentik_client.models.password_challenge_response_request import PasswordChallengeResponseRequest
from authentik_client.models.password_expiry_policy import PasswordExpiryPolicy
from authentik_client.models.password_expiry_policy_request import PasswordExpiryPolicyRequest
from authentik_client.models.password_policy import PasswordPolicy
from authentik_client.models.password_policy_request import PasswordPolicyRequest
from authentik_client.models.password_stage import PasswordStage
from authentik_client.models.password_stage_request import PasswordStageRequest
from authentik_client.models.patched_application_entitlement_request import PatchedApplicationEntitlementRequest
from authentik_client.models.patched_application_request import PatchedApplicationRequest
from authentik_client.models.patched_authenticator_duo_stage_request import PatchedAuthenticatorDuoStageRequest
from authentik_client.models.patched_authenticator_email_stage_request import PatchedAuthenticatorEmailStageRequest
from authentik_client.models.patched_authenticator_endpoint_gdtc_stage_request import PatchedAuthenticatorEndpointGDTCStageRequest
from authentik_client.models.patched_authenticator_sms_stage_request import PatchedAuthenticatorSMSStageRequest
from authentik_client.models.patched_authenticator_static_stage_request import PatchedAuthenticatorStaticStageRequest
from authentik_client.models.patched_authenticator_totp_stage_request import PatchedAuthenticatorTOTPStageRequest
from authentik_client.models.patched_authenticator_validate_stage_request import PatchedAuthenticatorValidateStageRequest
from authentik_client.models.patched_authenticator_web_authn_stage_request import PatchedAuthenticatorWebAuthnStageRequest
from authentik_client.models.patched_blueprint_instance_request import PatchedBlueprintInstanceRequest
from authentik_client.models.patched_brand_request import PatchedBrandRequest
from authentik_client.models.patched_captcha_stage_request import PatchedCaptchaStageRequest
from authentik_client.models.patched_certificate_key_pair_request import PatchedCertificateKeyPairRequest
from authentik_client.models.patched_connection_token_request import PatchedConnectionTokenRequest
from authentik_client.models.patched_consent_stage_request import PatchedConsentStageRequest
from authentik_client.models.patched_deny_stage_request import PatchedDenyStageRequest
from authentik_client.models.patched_docker_service_connection_request import PatchedDockerServiceConnectionRequest
from authentik_client.models.patched_domain_request import PatchedDomainRequest
from authentik_client.models.patched_dummy_policy_request import PatchedDummyPolicyRequest
from authentik_client.models.patched_dummy_stage_request import PatchedDummyStageRequest
from authentik_client.models.patched_duo_device_request import PatchedDuoDeviceRequest
from authentik_client.models.patched_email_device_request import PatchedEmailDeviceRequest
from authentik_client.models.patched_email_stage_request import PatchedEmailStageRequest
from authentik_client.models.patched_endpoint_device_request import PatchedEndpointDeviceRequest
from authentik_client.models.patched_endpoint_request import PatchedEndpointRequest
from authentik_client.models.patched_event_matcher_policy_request import PatchedEventMatcherPolicyRequest
from authentik_client.models.patched_event_request import PatchedEventRequest
from authentik_client.models.patched_expression_policy_request import PatchedExpressionPolicyRequest
from authentik_client.models.patched_extra_role_object_permission_request import PatchedExtraRoleObjectPermissionRequest
from authentik_client.models.patched_extra_user_object_permission_request import PatchedExtraUserObjectPermissionRequest
from authentik_client.models.patched_flow_request import PatchedFlowRequest
from authentik_client.models.patched_flow_stage_binding_request import PatchedFlowStageBindingRequest
from authentik_client.models.patched_geo_ip_policy_request import PatchedGeoIPPolicyRequest
from authentik_client.models.patched_google_workspace_provider_mapping_request import PatchedGoogleWorkspaceProviderMappingRequest
from authentik_client.models.patched_google_workspace_provider_request import PatchedGoogleWorkspaceProviderRequest
from authentik_client.models.patched_group_kerberos_source_connection_request import PatchedGroupKerberosSourceConnectionRequest
from authentik_client.models.patched_group_ldap_source_connection_request import PatchedGroupLDAPSourceConnectionRequest
from authentik_client.models.patched_group_o_auth_source_connection_request import PatchedGroupOAuthSourceConnectionRequest
from authentik_client.models.patched_group_plex_source_connection_request import PatchedGroupPlexSourceConnectionRequest
from authentik_client.models.patched_group_request import PatchedGroupRequest
from authentik_client.models.patched_group_saml_source_connection_request import PatchedGroupSAMLSourceConnectionRequest
from authentik_client.models.patched_group_source_connection_request import PatchedGroupSourceConnectionRequest
from authentik_client.models.patched_group_telegram_source_connection_request import PatchedGroupTelegramSourceConnectionRequest
from authentik_client.models.patched_identification_stage_request import PatchedIdentificationStageRequest
from authentik_client.models.patched_initial_permissions_request import PatchedInitialPermissionsRequest
from authentik_client.models.patched_invitation_request import PatchedInvitationRequest
from authentik_client.models.patched_invitation_stage_request import PatchedInvitationStageRequest
from authentik_client.models.patched_kerberos_source_property_mapping_request import PatchedKerberosSourcePropertyMappingRequest
from authentik_client.models.patched_kerberos_source_request import PatchedKerberosSourceRequest
from authentik_client.models.patched_kubernetes_service_connection_request import PatchedKubernetesServiceConnectionRequest
from authentik_client.models.patched_ldap_provider_request import PatchedLDAPProviderRequest
from authentik_client.models.patched_ldap_source_property_mapping_request import PatchedLDAPSourcePropertyMappingRequest
from authentik_client.models.patched_ldap_source_request import PatchedLDAPSourceRequest
from authentik_client.models.patched_license_request import PatchedLicenseRequest
from authentik_client.models.patched_microsoft_entra_provider_mapping_request import PatchedMicrosoftEntraProviderMappingRequest
from authentik_client.models.patched_microsoft_entra_provider_request import PatchedMicrosoftEntraProviderRequest
from authentik_client.models.patched_mutual_tls_stage_request import PatchedMutualTLSStageRequest
from authentik_client.models.patched_notification_request import PatchedNotificationRequest
from authentik_client.models.patched_notification_rule_request import PatchedNotificationRuleRequest
from authentik_client.models.patched_notification_transport_request import PatchedNotificationTransportRequest
from authentik_client.models.patched_notification_webhook_mapping_request import PatchedNotificationWebhookMappingRequest
from authentik_client.models.patched_o_auth2_provider_request import PatchedOAuth2ProviderRequest
from authentik_client.models.patched_o_auth_source_property_mapping_request import PatchedOAuthSourcePropertyMappingRequest
from authentik_client.models.patched_o_auth_source_request import PatchedOAuthSourceRequest
from authentik_client.models.patched_outpost_request import PatchedOutpostRequest
from authentik_client.models.patched_password_expiry_policy_request import PatchedPasswordExpiryPolicyRequest
from authentik_client.models.patched_password_policy_request import PatchedPasswordPolicyRequest
from authentik_client.models.patched_password_stage_request import PatchedPasswordStageRequest
from authentik_client.models.patched_permission_assign_request import PatchedPermissionAssignRequest
from authentik_client.models.patched_plex_source_property_mapping_request import PatchedPlexSourcePropertyMappingRequest
from authentik_client.models.patched_plex_source_request import PatchedPlexSourceRequest
from authentik_client.models.patched_policy_binding_request import PatchedPolicyBindingRequest
from authentik_client.models.patched_prompt_request import PatchedPromptRequest
from authentik_client.models.patched_prompt_stage_request import PatchedPromptStageRequest
from authentik_client.models.patched_proxy_provider_request import PatchedProxyProviderRequest
from authentik_client.models.patched_rac_property_mapping_request import PatchedRACPropertyMappingRequest
from authentik_client.models.patched_rac_provider_request import PatchedRACProviderRequest
from authentik_client.models.patched_radius_provider_property_mapping_request import PatchedRadiusProviderPropertyMappingRequest
from authentik_client.models.patched_radius_provider_request import PatchedRadiusProviderRequest
from authentik_client.models.patched_redirect_stage_request import PatchedRedirectStageRequest
from authentik_client.models.patched_reputation_policy_request import PatchedReputationPolicyRequest
from authentik_client.models.patched_role_request import PatchedRoleRequest
from authentik_client.models.patched_saml_property_mapping_request import PatchedSAMLPropertyMappingRequest
from authentik_client.models.patched_saml_provider_request import PatchedSAMLProviderRequest
from authentik_client.models.patched_saml_source_property_mapping_request import PatchedSAMLSourcePropertyMappingRequest
from authentik_client.models.patched_saml_source_request import PatchedSAMLSourceRequest
from authentik_client.models.patched_scim_mapping_request import PatchedSCIMMappingRequest
from authentik_client.models.patched_scim_provider_request import PatchedSCIMProviderRequest
from authentik_client.models.patched_scim_source_group_request import PatchedSCIMSourceGroupRequest
from authentik_client.models.patched_scim_source_property_mapping_request import PatchedSCIMSourcePropertyMappingRequest
from authentik_client.models.patched_scim_source_request import PatchedSCIMSourceRequest
from authentik_client.models.patched_scim_source_user_request import PatchedSCIMSourceUserRequest
from authentik_client.models.patched_sms_device_request import PatchedSMSDeviceRequest
from authentik_client.models.patched_ssf_provider_request import PatchedSSFProviderRequest
from authentik_client.models.patched_schedule_request import PatchedScheduleRequest
from authentik_client.models.patched_scope_mapping_request import PatchedScopeMappingRequest
from authentik_client.models.patched_settings_request import PatchedSettingsRequest
from authentik_client.models.patched_settings_request_flags import PatchedSettingsRequestFlags
from authentik_client.models.patched_source_stage_request import PatchedSourceStageRequest
from authentik_client.models.patched_static_device_request import PatchedStaticDeviceRequest
from authentik_client.models.patched_totp_device_request import PatchedTOTPDeviceRequest
from authentik_client.models.patched_telegram_source_property_mapping_request import PatchedTelegramSourcePropertyMappingRequest
from authentik_client.models.patched_telegram_source_request import PatchedTelegramSourceRequest
from authentik_client.models.patched_tenant_request import PatchedTenantRequest
from authentik_client.models.patched_token_request import PatchedTokenRequest
from authentik_client.models.patched_unique_password_policy_request import PatchedUniquePasswordPolicyRequest
from authentik_client.models.patched_user_delete_stage_request import PatchedUserDeleteStageRequest
from authentik_client.models.patched_user_kerberos_source_connection_request import PatchedUserKerberosSourceConnectionRequest
from authentik_client.models.patched_user_ldap_source_connection_request import PatchedUserLDAPSourceConnectionRequest
from authentik_client.models.patched_user_login_stage_request import PatchedUserLoginStageRequest
from authentik_client.models.patched_user_logout_stage_request import PatchedUserLogoutStageRequest
from authentik_client.models.patched_user_o_auth_source_connection_request import PatchedUserOAuthSourceConnectionRequest
from authentik_client.models.patched_user_plex_source_connection_request import PatchedUserPlexSourceConnectionRequest
from authentik_client.models.patched_user_request import PatchedUserRequest
from authentik_client.models.patched_user_saml_source_connection_request import PatchedUserSAMLSourceConnectionRequest
from authentik_client.models.patched_user_source_connection_request import PatchedUserSourceConnectionRequest
from authentik_client.models.patched_user_telegram_source_connection_request import PatchedUserTelegramSourceConnectionRequest
from authentik_client.models.patched_user_write_stage_request import PatchedUserWriteStageRequest
from authentik_client.models.patched_web_authn_device_request import PatchedWebAuthnDeviceRequest
from authentik_client.models.permission import Permission
from authentik_client.models.permission_assign_request import PermissionAssignRequest
from authentik_client.models.permission_assign_result import PermissionAssignResult
from authentik_client.models.permission_request import PermissionRequest
from authentik_client.models.plex_authentication_challenge import PlexAuthenticationChallenge
from authentik_client.models.plex_authentication_challenge_response_request import PlexAuthenticationChallengeResponseRequest
from authentik_client.models.plex_source import PlexSource
from authentik_client.models.plex_source_property_mapping import PlexSourcePropertyMapping
from authentik_client.models.plex_source_property_mapping_request import PlexSourcePropertyMappingRequest
from authentik_client.models.plex_source_request import PlexSourceRequest
from authentik_client.models.plex_token_redeem_request import PlexTokenRedeemRequest
from authentik_client.models.policy import Policy
from authentik_client.models.policy_binding import PolicyBinding
from authentik_client.models.policy_binding_request import PolicyBindingRequest
from authentik_client.models.policy_engine_mode import PolicyEngineMode
from authentik_client.models.policy_request import PolicyRequest
from authentik_client.models.policy_test_request import PolicyTestRequest
from authentik_client.models.policy_test_result import PolicyTestResult
from authentik_client.models.prompt import Prompt
from authentik_client.models.prompt_challenge import PromptChallenge
from authentik_client.models.prompt_challenge_response_request import PromptChallengeResponseRequest
from authentik_client.models.prompt_request import PromptRequest
from authentik_client.models.prompt_stage import PromptStage
from authentik_client.models.prompt_stage_request import PromptStageRequest
from authentik_client.models.prompt_type_enum import PromptTypeEnum
from authentik_client.models.property_mapping import PropertyMapping
from authentik_client.models.property_mapping_preview import PropertyMappingPreview
from authentik_client.models.property_mapping_test_request import PropertyMappingTestRequest
from authentik_client.models.property_mapping_test_result import PropertyMappingTestResult
from authentik_client.models.protocol_enum import ProtocolEnum
from authentik_client.models.provider import Provider
from authentik_client.models.provider_enum import ProviderEnum
from authentik_client.models.provider_model_enum import ProviderModelEnum
from authentik_client.models.provider_request import ProviderRequest
from authentik_client.models.provider_type_enum import ProviderTypeEnum
from authentik_client.models.proxy_mode import ProxyMode
from authentik_client.models.proxy_outpost_config import ProxyOutpostConfig
from authentik_client.models.proxy_provider import ProxyProvider
from authentik_client.models.proxy_provider_request import ProxyProviderRequest
from authentik_client.models.rac_property_mapping import RACPropertyMapping
from authentik_client.models.rac_property_mapping_request import RACPropertyMappingRequest
from authentik_client.models.rac_provider import RACProvider
from authentik_client.models.rac_provider_request import RACProviderRequest
from authentik_client.models.radius_check_access import RadiusCheckAccess
from authentik_client.models.radius_outpost_config import RadiusOutpostConfig
from authentik_client.models.radius_provider import RadiusProvider
from authentik_client.models.radius_provider_property_mapping import RadiusProviderPropertyMapping
from authentik_client.models.radius_provider_property_mapping_request import RadiusProviderPropertyMappingRequest
from authentik_client.models.radius_provider_request import RadiusProviderRequest
from authentik_client.models.redirect_challenge import RedirectChallenge
from authentik_client.models.redirect_challenge_response_request import RedirectChallengeResponseRequest
from authentik_client.models.redirect_stage import RedirectStage
from authentik_client.models.redirect_stage_mode_enum import RedirectStageModeEnum
from authentik_client.models.redirect_stage_request import RedirectStageRequest
from authentik_client.models.redirect_uri import RedirectURI
from authentik_client.models.redirect_uri_request import RedirectURIRequest
from authentik_client.models.reputation import Reputation
from authentik_client.models.reputation_policy import ReputationPolicy
from authentik_client.models.reputation_policy_request import ReputationPolicyRequest
from authentik_client.models.resident_key_requirement_enum import ResidentKeyRequirementEnum
from authentik_client.models.role import Role
from authentik_client.models.role_assigned_object_permission import RoleAssignedObjectPermission
from authentik_client.models.role_object_permission import RoleObjectPermission
from authentik_client.models.role_request import RoleRequest
from authentik_client.models.saml_metadata import SAMLMetadata
from authentik_client.models.saml_name_id_policy_enum import SAMLNameIDPolicyEnum
from authentik_client.models.saml_property_mapping import SAMLPropertyMapping
from authentik_client.models.saml_property_mapping_request import SAMLPropertyMappingRequest
from authentik_client.models.saml_provider import SAMLProvider
from authentik_client.models.saml_provider_request import SAMLProviderRequest
from authentik_client.models.saml_source import SAMLSource
from authentik_client.models.saml_source_property_mapping import SAMLSourcePropertyMapping
from authentik_client.models.saml_source_property_mapping_request import SAMLSourcePropertyMappingRequest
from authentik_client.models.saml_source_request import SAMLSourceRequest
from authentik_client.models.scim_authentication_mode_enum import SCIMAuthenticationModeEnum
from authentik_client.models.scim_mapping import SCIMMapping
from authentik_client.models.scim_mapping_request import SCIMMappingRequest
from authentik_client.models.scim_provider import SCIMProvider
from authentik_client.models.scim_provider_group import SCIMProviderGroup
from authentik_client.models.scim_provider_group_request import SCIMProviderGroupRequest
from authentik_client.models.scim_provider_request import SCIMProviderRequest
from authentik_client.models.scim_provider_user import SCIMProviderUser
from authentik_client.models.scim_provider_user_request import SCIMProviderUserRequest
from authentik_client.models.scim_source import SCIMSource
from authentik_client.models.scim_source_group import SCIMSourceGroup
from authentik_client.models.scim_source_group_request import SCIMSourceGroupRequest
from authentik_client.models.scim_source_property_mapping import SCIMSourcePropertyMapping
from authentik_client.models.scim_source_property_mapping_request import SCIMSourcePropertyMappingRequest
from authentik_client.models.scim_source_request import SCIMSourceRequest
from authentik_client.models.scim_source_user import SCIMSourceUser
from authentik_client.models.scim_source_user_request import SCIMSourceUserRequest
from authentik_client.models.sms_device import SMSDevice
from authentik_client.models.sms_device_request import SMSDeviceRequest
from authentik_client.models.ssf_provider import SSFProvider
from authentik_client.models.ssf_provider_request import SSFProviderRequest
from authentik_client.models.ssf_stream import SSFStream
from authentik_client.models.schedule import Schedule
from authentik_client.models.schedule_request import ScheduleRequest
from authentik_client.models.scope_mapping import ScopeMapping
from authentik_client.models.scope_mapping_request import ScopeMappingRequest
from authentik_client.models.selectable_stage import SelectableStage
from authentik_client.models.service_connection import ServiceConnection
from authentik_client.models.service_connection_request import ServiceConnectionRequest
from authentik_client.models.service_connection_state import ServiceConnectionState
from authentik_client.models.session_end_challenge import SessionEndChallenge
from authentik_client.models.session_user import SessionUser
from authentik_client.models.settings import Settings
from authentik_client.models.settings_request import SettingsRequest
from authentik_client.models.severity_enum import SeverityEnum
from authentik_client.models.shell_challenge import ShellChallenge
from authentik_client.models.signature_algorithm_enum import SignatureAlgorithmEnum
from authentik_client.models.source import Source
from authentik_client.models.source_request import SourceRequest
from authentik_client.models.source_stage import SourceStage
from authentik_client.models.source_stage_request import SourceStageRequest
from authentik_client.models.source_type import SourceType
from authentik_client.models.sp_binding_enum import SpBindingEnum
from authentik_client.models.stage import Stage
from authentik_client.models.stage_prompt import StagePrompt
from authentik_client.models.stage_request import StageRequest
from authentik_client.models.state_enum import StateEnum
from authentik_client.models.static_device import StaticDevice
from authentik_client.models.static_device_request import StaticDeviceRequest
from authentik_client.models.static_device_token import StaticDeviceToken
from authentik_client.models.sub_mode_enum import SubModeEnum
from authentik_client.models.sync_object_model_enum import SyncObjectModelEnum
from authentik_client.models.sync_object_request import SyncObjectRequest
from authentik_client.models.sync_object_result import SyncObjectResult
from authentik_client.models.sync_status import SyncStatus
from authentik_client.models.system_info import SystemInfo
from authentik_client.models.system_info_runtime import SystemInfoRuntime
from authentik_client.models.totp_device import TOTPDevice
from authentik_client.models.totp_device_request import TOTPDeviceRequest
from authentik_client.models.task import Task
from authentik_client.models.task_aggregated_status_enum import TaskAggregatedStatusEnum
from authentik_client.models.telegram_challenge_response_request import TelegramChallengeResponseRequest
from authentik_client.models.telegram_login_challenge import TelegramLoginChallenge
from authentik_client.models.telegram_source import TelegramSource
from authentik_client.models.telegram_source_property_mapping import TelegramSourcePropertyMapping
from authentik_client.models.telegram_source_property_mapping_request import TelegramSourcePropertyMappingRequest
from authentik_client.models.telegram_source_request import TelegramSourceRequest
from authentik_client.models.tenant import Tenant
from authentik_client.models.tenant_admin_group_request_request import TenantAdminGroupRequestRequest
from authentik_client.models.tenant_recovery_key_request_request import TenantRecoveryKeyRequestRequest
from authentik_client.models.tenant_recovery_key_response import TenantRecoveryKeyResponse
from authentik_client.models.tenant_request import TenantRequest
from authentik_client.models.token import Token
from authentik_client.models.token_model import TokenModel
from authentik_client.models.token_request import TokenRequest
from authentik_client.models.token_set_key_request import TokenSetKeyRequest
from authentik_client.models.token_view import TokenView
from authentik_client.models.transaction_application_request import TransactionApplicationRequest
from authentik_client.models.transaction_application_response import TransactionApplicationResponse
from authentik_client.models.transaction_policy_binding_request import TransactionPolicyBindingRequest
from authentik_client.models.type_create import TypeCreate
from authentik_client.models.ui_theme_enum import UiThemeEnum
from authentik_client.models.unique_password_policy import UniquePasswordPolicy
from authentik_client.models.unique_password_policy_request import UniquePasswordPolicyRequest
from authentik_client.models.used_by import UsedBy
from authentik_client.models.used_by_action_enum import UsedByActionEnum
from authentik_client.models.user import User
from authentik_client.models.user_account_request import UserAccountRequest
from authentik_client.models.user_assigned_object_permission import UserAssignedObjectPermission
from authentik_client.models.user_attribute_enum import UserAttributeEnum
from authentik_client.models.user_consent import UserConsent
from authentik_client.models.user_creation_mode_enum import UserCreationModeEnum
from authentik_client.models.user_delete_stage import UserDeleteStage
from authentik_client.models.user_delete_stage_request import UserDeleteStageRequest
from authentik_client.models.user_fields_enum import UserFieldsEnum
from authentik_client.models.user_kerberos_source_connection import UserKerberosSourceConnection
from authentik_client.models.user_kerberos_source_connection_request import UserKerberosSourceConnectionRequest
from authentik_client.models.user_ldap_source_connection import UserLDAPSourceConnection
from authentik_client.models.user_ldap_source_connection_request import UserLDAPSourceConnectionRequest
from authentik_client.models.user_login_challenge import UserLoginChallenge
from authentik_client.models.user_login_challenge_response_request import UserLoginChallengeResponseRequest
from authentik_client.models.user_login_stage import UserLoginStage
from authentik_client.models.user_login_stage_request import UserLoginStageRequest
from authentik_client.models.user_logout_stage import UserLogoutStage
from authentik_client.models.user_logout_stage_request import UserLogoutStageRequest
from authentik_client.models.user_matching_mode_enum import UserMatchingModeEnum
from authentik_client.models.user_o_auth_source_connection import UserOAuthSourceConnection
from authentik_client.models.user_o_auth_source_connection_request import UserOAuthSourceConnectionRequest
from authentik_client.models.user_object_permission import UserObjectPermission
from authentik_client.models.user_password_set_request import UserPasswordSetRequest
from authentik_client.models.user_path import UserPath
from authentik_client.models.user_plex_source_connection import UserPlexSourceConnection
from authentik_client.models.user_plex_source_connection_request import UserPlexSourceConnectionRequest
from authentik_client.models.user_request import UserRequest
from authentik_client.models.user_saml_source_connection import UserSAMLSourceConnection
from authentik_client.models.user_saml_source_connection_request import UserSAMLSourceConnectionRequest
from authentik_client.models.user_self import UserSelf
from authentik_client.models.user_self_groups import UserSelfGroups
from authentik_client.models.user_service_account_request import UserServiceAccountRequest
from authentik_client.models.user_service_account_response import UserServiceAccountResponse
from authentik_client.models.user_setting import UserSetting
from authentik_client.models.user_source_connection import UserSourceConnection
from authentik_client.models.user_source_connection_request import UserSourceConnectionRequest
from authentik_client.models.user_telegram_source_connection import UserTelegramSourceConnection
from authentik_client.models.user_telegram_source_connection_request import UserTelegramSourceConnectionRequest
from authentik_client.models.user_type_enum import UserTypeEnum
from authentik_client.models.user_verification_enum import UserVerificationEnum
from authentik_client.models.user_write_stage import UserWriteStage
from authentik_client.models.user_write_stage_request import UserWriteStageRequest
from authentik_client.models.validation_error import ValidationError
from authentik_client.models.version import Version
from authentik_client.models.version_history import VersionHistory
from authentik_client.models.web_authn_device import WebAuthnDevice
from authentik_client.models.web_authn_device_request import WebAuthnDeviceRequest
from authentik_client.models.web_authn_device_type import WebAuthnDeviceType
from authentik_client.models.worker import Worker

""",
            name=__name__,
            doc=__doc__,
        )
    )
